@@ -72,7 +72,7 @@ import org.apache.tools.ant.util.SourceFileScanner;
  * is older than the XML file will be compiled.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRAntCompileTask.java 3932 2010-08-04 12:17:40Z teodord $
+ * @version $Id: JRAntCompileTask.java 3653 2010-03-30 16:12:52Z teodord $
  */
 public class JRAntCompileTask extends MatchingTask
 {
@@ -81,15 +81,15 @@ public class JRAntCompileTask extends MatchingTask
 	/**
 	 *
 	 */
-	private Path src;
-	private File destdir;
-	private File tempdir;
-	private boolean keepjava;
-	private String compiler;
-	private Path classpath;
+	private Path src = null;
+	private File destdir = null;
+	private File tempdir = null;
+	private boolean keepjava = false;
+	private String compiler = null;
+	private Path classpath = null;
 	private boolean xmlvalidation = true;
 
-	private Map reportFilesMap;
+	private Map reportFilesMap = null;
 
 
 	/**
