@@ -38,7 +38,7 @@ import net.sf.jasperreports.engine.fill.JRFillObjectFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillCategorySeries.java 3938 2010-08-19 14:59:36Z teodord $
+ * @version $Id: JRFillCategorySeries.java 3876 2010-07-14 14:18:47Z shertage $
  */
 public class JRFillCategorySeries implements JRCategorySeries
 {
@@ -46,12 +46,12 @@ public class JRFillCategorySeries implements JRCategorySeries
 	/**
 	 *
 	 */
-	protected JRCategorySeries parent;
+	protected JRCategorySeries parent = null;
 
-	private Comparable series;
-	private Comparable category;
-	private Number value;
-	private String label;
+	private Comparable series = null;
+	private Comparable category = null;
+	private Number value = null;
+	private String label = null;
 	private JRPrintHyperlink itemHyperlink;
 	
 	
