@@ -41,7 +41,7 @@ import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
  * Common usages are to show "critical", "warning" and "good" ranges.
  *
  * @author Barry Klawans (barry@users.sourceforge.net)
- * @version $Id: JRMeterInterval.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRMeterInterval.java 3715 2010-04-08 18:08:49Z teodord $
  */
 
 
@@ -52,23 +52,23 @@ public class JRMeterInterval implements JRCloneable, Serializable
 	/**
 	 * The range of this interval.  Must be inside the meter's range.
 	 */
-	protected JRDataRange dataRange;
+	protected JRDataRange dataRange = null;
 
 	/**
 	 * The label of this interval.  Only appears in the meter's legend.
 	 */
-	protected String label;
+	protected String label = null;
 
 	/**
 	 * Color to use to shade in this region on the meter's face.
 	 */
-	protected Color backgroundColor;
+	protected Color backgroundColor = null;
 
 	/**
 	 * Transparency of the interval's color.  1.0 is fully opaque, 0.0 is
 	 * fully transparent.
 	 */
-	protected Double alphaDouble;
+	protected Double alphaDouble = null;
 
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
