@@ -33,7 +33,7 @@ import org.xml.sax.Attributes;
 
 /**
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRPie3DPlotFactory.java 3948 2010-09-01 12:07:07Z shertage $
+ * @version $Id: JRPie3DPlotFactory.java 3616 2010-03-24 14:20:41Z teodord $
  */
 public class JRPie3DPlotFactory extends JRBaseFactory
 {
@@ -41,7 +41,6 @@ public class JRPie3DPlotFactory extends JRBaseFactory
 	 *
 	 */
 	private static final String ATTRIBUTE_depthFactor = "depthFactor";
-	private static final String ATTRIBUTE_isShowLabels = "isShowLabels";
 
 	/**
 	 *
@@ -65,10 +64,6 @@ public class JRPie3DPlotFactory extends JRBaseFactory
 		pie3DPlot.setLabelFormat(atts.getValue(JRXmlConstants.ATTRIBUTE_labelFormat));
 		pie3DPlot.setLegendLabelFormat(atts.getValue(JRXmlConstants.ATTRIBUTE_legendLabelFormat));
 
-		String isShowLabels = atts.getValue( ATTRIBUTE_isShowLabels );
-		if( isShowLabels != null && isShowLabels.length() > 0 ){
-			pie3DPlot.setShowLabels(Boolean.valueOf(isShowLabels));
-		}
 		return pie3DPlot;
 	}
 }
