@@ -33,11 +33,10 @@ import org.xml.sax.Attributes;
 
 /**
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRPiePlotFactory.java 3948 2010-09-01 12:07:07Z shertage $
+ * @version $Id: JRPiePlotFactory.java 3616 2010-03-24 14:20:41Z teodord $
  */
 public class JRPiePlotFactory extends JRBaseFactory
 {
-	private static final String ATTRIBUTE_isShowLabels = "isShowLabels";
 
 	/**
 	 * 
@@ -55,11 +54,6 @@ public class JRPiePlotFactory extends JRBaseFactory
 		piePlot.setLabelFormat(atts.getValue(JRXmlConstants.ATTRIBUTE_labelFormat));
 		piePlot.setLegendLabelFormat(atts.getValue(JRXmlConstants.ATTRIBUTE_legendLabelFormat));
 
-		String isShowLabels = atts.getValue( ATTRIBUTE_isShowLabels );
-		if( isShowLabels != null && isShowLabels.length() > 0 ){
-			piePlot.setShowLabels(Boolean.valueOf(isShowLabels));
-		}
-
 		return piePlot;	
 	}
 }
