@@ -40,7 +40,7 @@ import bsh.TargetError;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBshEvaluator.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRBshEvaluator.java 3717 2010-04-09 10:01:33Z teodord $
  */
 public class JRBshEvaluator extends JREvaluator
 {
@@ -49,8 +49,8 @@ public class JRBshEvaluator extends JREvaluator
 	/**
 	 *
 	 */
-	private String bshScript;
-	private Interpreter interpreter;
+	private String bshScript = null;
+	private Interpreter interpreter = null;
 
 
 	/**
