@@ -24,8 +24,8 @@
 package net.sf.jasperreports.crosstabs.fill.calculation;
 
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.Comparator;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
@@ -37,19 +37,20 @@ import java.util.Map.Entry;
 
 import net.sf.jasperreports.crosstabs.fill.calculation.BucketDefinition.Bucket;
 import net.sf.jasperreports.crosstabs.fill.calculation.MeasureDefinition.MeasureValue;
+import net.sf.jasperreports.crosstabs.type.CrosstabTotalPositionEnum;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRRuntimeException;
-import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.fill.JRCalculable;
 import net.sf.jasperreports.engine.fill.JRFillCrosstab;
+import net.sf.jasperreports.engine.type.CalculationEnum;
 import net.sf.jasperreports.engine.util.JRProperties;
 
 /**
  * Crosstab bucketing engine.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: BucketingService.java 3203 2009-11-19 17:44:16Z lucianc $
+ * @version $Id: BucketingService.java 3676 2010-04-02 09:35:07Z shertage $
  */
 public class BucketingService
 {
@@ -258,22 +259,22 @@ public class BucketingService
 	{
 		switch (measure.getCalculation())
 		{
-			case JRVariable.CALCULATION_AVERAGE:
-			case JRVariable.CALCULATION_VARIANCE:
+			case AVERAGE:
+			case VARIANCE:
 			{
-				MeasureDefinition sumMeasure = MeasureDefinition.createHelperMeasure(measure, JRVariable.CALCULATION_SUM);
+				MeasureDefinition sumMeasure = MeasureDefinition.createHelperMeasure(measure, CalculationEnum.SUM);
 				addMeasure(sumMeasure, index, measuresList, measureIndexList);
-				MeasureDefinition countMeasure = MeasureDefinition.createHelperMeasure(measure, JRVariable.CALCULATION_COUNT);
+				MeasureDefinition countMeasure = MeasureDefinition.createHelperMeasure(measure, CalculationEnum.COUNT);
 				addMeasure(countMeasure, index, measuresList, measureIndexList);
 				break;
 			}
-			case JRVariable.CALCULATION_STANDARD_DEVIATION:
+			case STANDARD_DEVIATION:
 			{
-				MeasureDefinition varianceMeasure = MeasureDefinition.createHelperMeasure(measure, JRVariable.CALCULATION_VARIANCE);
+				MeasureDefinition varianceMeasure = MeasureDefinition.createHelperMeasure(measure, CalculationEnum.VARIANCE);
 				addMeasure(varianceMeasure, index, measuresList, measureIndexList);
 				break;
 			}
-			case JRVariable.CALCULATION_DISTINCT_COUNT:
+			case DISTINCT_COUNT:
 			{
 				MeasureDefinition countMeasure = MeasureDefinition.createDistinctCountHelperMeasure(measure);
 				addMeasure(countMeasure, index, measuresList, measureIndexList);
@@ -282,7 +283,7 @@ public class BucketingService
 		}
 
 		measuresList.add(measure);
-		measureIndexList.add(new Integer(index));
+		measureIndexList.add(Integer.valueOf(index));
 	}
 
 	
@@ -346,18 +347,18 @@ public class BucketingService
 
 			switch (measure.getCalculation())
 			{
-				case JRVariable.CALCULATION_AVERAGE:
-				case JRVariable.CALCULATION_VARIANCE:
+				case AVERAGE:
+				case VARIANCE:
 				{
 					values[i].setHelper(values[i - 2], JRCalculable.HELPER_SUM);
 					values[i].setHelper(values[i - 1], JRCalculable.HELPER_COUNT);
 					break;
 				}
-				case JRVariable.CALCULATION_STANDARD_DEVIATION:
+				case STANDARD_DEVIATION:
 				{
 					values[i].setHelper(values[i - 1], JRCalculable.HELPER_VARIANCE);
 				}
-				case JRVariable.CALCULATION_DISTINCT_COUNT:
+				case DISTINCT_COUNT:
 				{
 					values[i].setHelper(values[i - 1], JRCalculable.HELPER_COUNT);
 				}
@@ -662,8 +663,6 @@ public class BucketingService
 			addTotalEntry(nextMap);
 			return nextMap;
 		}
-		
-		abstract void set(Bucket key, Object value);
 
 		abstract void clear();
 
@@ -756,16 +755,14 @@ public class BucketingService
 		{
 			return map.toString();
 		}
-
-		void set(Bucket key, Object value)
-		{
-			map.put(key, value);
-		}
 	}
 
 	protected class BucketListMap extends BucketMap
 	{
 		List entries;
+		// we maintain a map as well in order to have fast search by key
+		// TODO implement this in a single structure
+		Map entryMap;
 
 		BucketListMap(int level, boolean linked)
 		{
@@ -779,11 +776,14 @@ public class BucketingService
 			{
 				entries = new ArrayList();
 			}
+			
+			entryMap = new HashMap();
 		}
 
 		void clear()
 		{
 			entries.clear();
+			entryMap.clear();
 		}
 		
 		Iterator entryIterator()
@@ -794,12 +794,12 @@ public class BucketingService
 		private void add(Bucket key, Object value)
 		{
 			entries.add(new MapEntry(key, value));
+			entryMap.put(key, value);
 		}
 
 		Object get(Bucket key)
 		{
-			int idx = Collections.binarySearch(entries, new MapEntry(key, null));
-			return idx >= 0 ? ((MapEntry) entries.get(idx)).value : null;
+			return entryMap.get(key);
 		}
 
 		MeasureValue[] insertMeasureValues(Bucket[] bucketValues)
@@ -868,14 +868,6 @@ public class BucketingService
 			return null;
 		}
 
-		void set(Bucket key, Object value)
-		{
-			MapEntry mapEntry = new MapEntry(key, value);
-			int idx = Collections.binarySearch(entries, mapEntry);
-			int ins = -idx - 1;
-			entries.add(ins, mapEntry);
-		}
-
 		
 		void collectVals(BucketMap map, boolean sum) throws JRException
 		{
@@ -927,7 +919,10 @@ public class BucketingService
 						{
 							totalIt.previous();
 						}
+						
 						totalIt.add(new MapEntry(key, addVal));
+						entryMap.put(key, addVal);
+						
 						if (totalItEntry != null)
 						{
 							totalIt.next();
@@ -1043,7 +1038,7 @@ public class BucketingService
 			throws JRException
 	{
 		BucketDefinition bucketDefinition = allBuckets[bucketMap.level];
-		byte totalPosition = bucketDefinition.getTotalPosition();
+		CrosstabTotalPositionEnum totalPosition = bucketDefinition.getTotalPosition();
 		CollectedList headers;
 		if (bucketDefinition.hasOrderValues())
 		{
@@ -1060,7 +1055,7 @@ public class BucketingService
 			Bucket bucketValue = (Bucket) entry.getKey();
 
 			boolean totalBucket = bucketValue.isTotal();
-			boolean createHeader = !totalBucket || total || totalPosition != BucketDefinition.TOTAL_POSITION_NONE;
+			boolean createHeader = !totalBucket || total || totalPosition != CrosstabTotalPositionEnum.NONE;
 
 			if (createHeader)
 			{
@@ -1072,7 +1067,7 @@ public class BucketingService
 				}
 				else
 				{
-					nextHeaders = new SequentialCollectedList(BucketDefinition.TOTAL_POSITION_NONE);
+					nextHeaders = new SequentialCollectedList(CrosstabTotalPositionEnum.NONE);
 					nextHeaders.span = 1;
 				}
 				nextHeaders.key = bucketValue;
@@ -1347,10 +1342,10 @@ public class BucketingService
 	{
 		private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
-		final byte totalPosition;
+		final CrosstabTotalPositionEnum totalPosition;
 		final LinkedList list;
 		
-		SequentialCollectedList(byte totalPosition)
+		SequentialCollectedList(CrosstabTotalPositionEnum totalPosition)
 		{
 			this.totalPosition = totalPosition;
 			
@@ -1364,7 +1359,7 @@ public class BucketingService
 
 		protected void addSublist(CollectedList sublist)
 		{
-			if (sublist.key.isTotal() && totalPosition == BucketDefinition.TOTAL_POSITION_START)
+			if (sublist.key.isTotal() && totalPosition == CrosstabTotalPositionEnum.START)
 			{
 				list.addFirst(sublist);
 			}
@@ -1410,7 +1405,7 @@ public class BucketingService
 		{
 			this.bucketDefinition = bucketDefinition;
 			this.totalFirst = bucketDefinition.getTotalPosition() 
-					== BucketDefinition.TOTAL_POSITION_START;
+					== CrosstabTotalPositionEnum.START;
 		}
 
 		public int compare(Object o1, Object o2)
