@@ -48,7 +48,7 @@ import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
  * The base implementation of {@link net.sf.jasperreports.engine.JRDataset JRDataset}.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRBaseDataset.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRBaseDataset.java 3715 2010-04-08 18:08:49Z teodord $
  */
 public class JRBaseDataset implements JRDataset, Serializable, JRChangeEventsSupport
 {
@@ -57,16 +57,16 @@ public class JRBaseDataset implements JRDataset, Serializable, JRChangeEventsSup
 	public static final String PROPERTY_WHEN_RESOURCE_MISSING_TYPE = "whenResourceMissingType";
 
 	protected final boolean isMain;
-	protected String name;
-	protected String scriptletClass;
-	protected JRScriptlet[] scriptlets;
-	protected JRParameter[] parameters;
-	protected JRQuery query;
-	protected JRField[] fields;
-	protected JRSortField[] sortFields;
-	protected JRVariable[] variables;
-	protected JRGroup[] groups;
-	protected String resourceBundle;
+	protected String name = null;
+	protected String scriptletClass = null;
+	protected JRScriptlet[] scriptlets = null;
+	protected JRParameter[] parameters = null;
+	protected JRQuery query = null;
+	protected JRField[] fields = null;
+	protected JRSortField[] sortFields = null;
+	protected JRVariable[] variables = null;
+	protected JRGroup[] groups = null;
+	protected String resourceBundle = null;
 	protected WhenResourceMissingTypeEnum whenResourceMissingTypeValue = WhenResourceMissingTypeEnum.NULL;
 	protected JRPropertiesMap propertiesMap;
 	protected JRExpression filterExpression;
