@@ -42,7 +42,7 @@ import net.sf.jasperreports.engine.util.JRTextAttribute;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseFont.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRBaseFont.java 3676 2010-04-02 09:35:07Z shertage $
  */
 public class JRBaseFont implements JRFont, Serializable, JRChangeEventsSupport
 {
@@ -76,27 +76,27 @@ public class JRBaseFont implements JRFont, Serializable, JRChangeEventsSupport
 	/**
 	 *
 	 */
-	protected JRDefaultFontProvider defaultFontProvider;
+	protected JRDefaultFontProvider defaultFontProvider = null;
 
 	/**
 	 *
 	 */
-	protected JRReportFont reportFont;
+	protected JRReportFont reportFont = null;
 
 	/**
 	 *
 	 */
-	protected JRStyleContainer styleContainer;
+	protected JRStyleContainer styleContainer = null;
 
-	protected String fontName;
-	protected Boolean isBold;
-	protected Boolean isItalic;
-	protected Boolean isUnderline;
-	protected Boolean isStrikeThrough;
-	protected Integer fontSize;
-	protected String pdfFontName;
-	protected String pdfEncoding;
-	protected Boolean isPdfEmbedded;
+	protected String fontName = null;
+	protected Boolean isBold = null;
+	protected Boolean isItalic = null;
+	protected Boolean isUnderline = null;
+	protected Boolean isStrikeThrough = null;
+	protected Integer fontSize = null;
+	protected String pdfFontName = null;
+	protected String pdfEncoding = null;
+	protected Boolean isPdfEmbedded = null;
 
 
 	/**
