@@ -153,7 +153,7 @@ import net.sf.jasperreports.engine.JRVariable;
  * Factory of objects used in compiled reports.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseObjectFactory.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRBaseObjectFactory.java 3741 2010-04-16 15:58:45Z lucianc $
  */
 public class JRBaseObjectFactory extends JRAbstractObjectFactory
 {
@@ -162,7 +162,7 @@ public class JRBaseObjectFactory extends JRAbstractObjectFactory
 	/**
 	 *
 	 */
-	private JRDefaultStyleProvider defaultStyleProvider;
+	private JRDefaultStyleProvider defaultStyleProvider = null;
 
 	/**
 	 * Expression collector used to retrieve generated expression IDs.
