@@ -38,7 +38,6 @@ import net.sf.jasperreports.engine.JRPrintHyperlinkParameter;
 import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.JRRenderable;
-import net.sf.jasperreports.engine.PrintElementVisitor;
 import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
@@ -54,7 +53,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBasePrintImage.java 3991 2010-10-12 20:10:55Z lucianc $
+ * @version $Id: JRBasePrintImage.java 3833 2010-05-27 14:16:59Z teodord $
  */
 public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPrintImage
 {
@@ -68,20 +67,20 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	/**
 	 *
 	 */
-	protected JRRenderable renderer;
-	protected ScaleImageEnum scaleImageValue;
+	protected JRRenderable renderer = null;
+	protected ScaleImageEnum scaleImageValue = null;
 	protected Boolean isUsingCache = Boolean.TRUE;
-	protected HorizontalAlignEnum horizontalAlignmentValue;
-	protected VerticalAlignEnum verticalAlignmentValue;
-	protected boolean isLazy;
+	protected HorizontalAlignEnum horizontalAlignmentValue = null;
+	protected VerticalAlignEnum verticalAlignmentValue = null;
+	protected boolean isLazy = false;
 	protected OnErrorTypeEnum onErrorTypeValue = OnErrorTypeEnum.ERROR;
-	protected JRLineBox lineBox;
-	protected String anchorName;
+	protected JRLineBox lineBox = null;
+	protected String anchorName = null;
 	protected String linkType;
 	protected String linkTarget;
-	protected String hyperlinkReference;
-	protected String hyperlinkAnchor;
-	protected Integer hyperlinkPage;
+	protected String hyperlinkReference = null;
+	protected String hyperlinkAnchor = null;
+	protected Integer hyperlinkPage = null;
 	protected String hyperlinkTooltip;
 	protected JRPrintHyperlinkParameters hyperlinkParameters;
 
@@ -1060,71 +1059,71 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	/**
 	 * @deprecated
 	 */
-	private Byte horizontalAlignment;
+	private Byte horizontalAlignment = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte verticalAlignment;
+	private Byte verticalAlignment = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte border;
+	private Byte border = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte topBorder;
+	private Byte topBorder = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte leftBorder;
+	private Byte leftBorder = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte bottomBorder;
+	private Byte bottomBorder = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte rightBorder;
+	private Byte rightBorder = null;
 	/**
 	 * @deprecated
 	 */
-	private Color borderColor;
+	private Color borderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Color topBorderColor;
+	private Color topBorderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Color leftBorderColor;
+	private Color leftBorderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Color bottomBorderColor;
+	private Color bottomBorderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Color rightBorderColor;
+	private Color rightBorderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer padding;
+	private Integer padding = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer topPadding;
+	private Integer topPadding = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer leftPadding;
+	private Integer leftPadding = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer bottomPadding;
+	private Integer bottomPadding = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer rightPadding;
+	private Integer rightPadding = null;
 	/**
 	 * @deprecated
 	 */
@@ -1136,7 +1135,7 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	/**
 	 * @deprecated
 	 */
-	private Byte scaleImage;
+	private Byte scaleImage = null;
 	/**
 	 * @deprecated
 	 */
@@ -1207,10 +1206,4 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 			 linkTarget = JRHyperlinkHelper.getLinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
 		}
 	}
-
-
-	public <T> void accept(PrintElementVisitor<T> visitor, T arg)
-	{
-		visitor.visit(this, arg);
-	}
 }
