@@ -32,13 +32,12 @@ import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRSortField;
 import net.sf.jasperreports.engine.design.events.JRChangeEventsSupport;
 import net.sf.jasperreports.engine.design.events.JRPropertyChangeSupport;
-import net.sf.jasperreports.engine.type.SortFieldTypeEnum;
 import net.sf.jasperreports.engine.type.SortOrderEnum;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseSortField.java 3957 2010-09-22 08:54:46Z teodord $
+ * @version $Id: JRBaseSortField.java 3715 2010-04-08 18:08:49Z teodord $
  */
 public class JRBaseSortField implements JRSortField, Serializable, JRChangeEventsSupport
 {
@@ -54,9 +53,8 @@ public class JRBaseSortField implements JRSortField, Serializable, JRChangeEvent
 	/**
 	 *
 	 */
-	protected String name;
+	protected String name = null;
 	protected SortOrderEnum orderValue = SortOrderEnum.ASCENDING;
-	protected SortFieldTypeEnum type = SortFieldTypeEnum.FIELD;
 
 
 	/**
@@ -76,7 +74,6 @@ public class JRBaseSortField implements JRSortField, Serializable, JRChangeEvent
 		
 		name = sortField.getName();
 		orderValue = sortField.getOrderValue();
-		type = sortField.getType();
 	}
 		
 
@@ -122,14 +119,6 @@ public class JRBaseSortField implements JRSortField, Serializable, JRChangeEvent
 		getEventSupport().firePropertyChange(PROPERTY_ORDER, old, this.orderValue);
 	}
 	
-	/**
-	 *
-	 */
-	public SortFieldTypeEnum getType()
-	{
-		return type;
-	}
-		
 	/**
 	 * 
 	 */
@@ -178,11 +167,6 @@ public class JRBaseSortField implements JRSortField, Serializable, JRChangeEvent
 		{
 			orderValue = SortOrderEnum.getByValue((byte)(order + 1));
 		}
-		
-		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_5)
-		{
-			type = SortFieldTypeEnum.FIELD;
-		}
 	}
 	
 }
