@@ -73,7 +73,7 @@ import org.jfree.date.DateUtilities;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ConvertChartContext.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: ConvertChartContext.java 3690 2010-04-06 12:23:17Z shertage $
  */
 public class ConvertChartContext implements ChartContext
 {
@@ -146,7 +146,7 @@ public class ConvertChartContext implements ChartContext
 		return null;
 	}
 	
-	private static DefaultCategoryDataset sampleCategoryDataset;
+	private static DefaultCategoryDataset sampleCategoryDataset = null;
 	
 	private CategoryDataset createCategoryDataset()
 	{
@@ -184,7 +184,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleCategoryDataset;
 	}
 	
-	private static PieDataset samplePieDataset;
+	private static PieDataset samplePieDataset = null;
 	
 	private PieDataset createPieDataset()
 	{
@@ -203,7 +203,7 @@ public class ConvertChartContext implements ChartContext
 		return samplePieDataset;
 	}
 	
-	private static XYSeriesCollection sampleXyDataset;
+	private static XYSeriesCollection sampleXyDataset = null;
 	
 	private XYDataset createXyDataset()
 	{
@@ -253,7 +253,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleXyDataset;
 	}
 	
-	private static TimeSeriesCollection sampleTimeSeriesDataset;
+	private static TimeSeriesCollection sampleTimeSeriesDataset = null;
 	
 	private TimeSeriesCollection createTimeSeriesDataset()
 	{
@@ -325,7 +325,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleTimeSeriesDataset;
 	}
 	
-	private static DefaultXYZDataset sampleXyzDataset;
+	private static DefaultXYZDataset sampleXyzDataset = null;
 	
 	private XYZDataset createXyzDataset()
 	{
@@ -348,7 +348,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleXyzDataset;
 	}
 
-	private static TaskSeriesCollection sampleGanttDataset;
+	private static TaskSeriesCollection sampleGanttDataset = null;
 	
 	private IntervalCategoryDataset createGanttDataset() 
 	{
@@ -385,7 +385,7 @@ public class ConvertChartContext implements ChartContext
 		return calendar.getTime();
 	}
 
-	private static DefaultHighLowDataset sampleHighLowDataset;
+	private static DefaultHighLowDataset sampleHighLowDataset = null;
 	
 	private OHLCDataset createHighLowDataset() 
 	{
@@ -736,7 +736,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleHighLowDataset;
 	}
 	
-	private static TimePeriodValuesCollection sampleTimePeriodDataset;
+	private static TimePeriodValuesCollection sampleTimePeriodDataset = null;
 	
 	private XYDataset createTimePeriodDataset()
 	{
