@@ -62,14 +62,14 @@ import net.sf.jasperreports.engine.type.ModeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ConvertVisitor.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: ConvertVisitor.java 3467 2010-02-23 13:11:13Z teodord $
  */
 public class ConvertVisitor implements JRVisitor
 {
 	
-	private ReportConverter reportConverter;
-	private JRBasePrintFrame parentFrame;
-	private JRPrintElement printElement;
+	private ReportConverter reportConverter = null;
+	private JRBasePrintFrame parentFrame = null;
+	private JRPrintElement printElement = null;
 	
 	/**
 	 *
