@@ -58,6 +58,8 @@ import net.sf.jasperreports.engine.JRVirtualizer;
 import net.sf.jasperreports.engine.JasperReport;
 import net.sf.jasperreports.engine.base.JRBaseDataset;
 import net.sf.jasperreports.engine.query.JRQueryExecuterFactory;
+import net.sf.jasperreports.engine.type.CalculationEnum;
+import net.sf.jasperreports.engine.type.ResetTypeEnum;
 import net.sf.jasperreports.engine.util.FileResolver;
 import net.sf.jasperreports.engine.util.FormatFactory;
 import net.sf.jasperreports.engine.util.JRQueryExecuterUtils;
@@ -66,7 +68,7 @@ import net.sf.jasperreports.engine.util.JRQueryExecuterUtils;
  * Implementation of {@link net.sf.jasperreports.engine.JRDataset JRDataset} to be used for report desing.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignDataset.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRDesignDataset.java 3861 2010-06-04 11:17:45Z teodord $
  */
 public class JRDesignDataset extends JRBaseDataset
 {
@@ -162,7 +164,8 @@ public class JRDesignDataset extends JRBaseDataset
 		JRParameter.REPORT_FORMAT_FACTORY, FormatFactory.class, 
 		JRParameter.REPORT_CLASS_LOADER, ClassLoader.class,
 		JRParameter.REPORT_URL_HANDLER_FACTORY, URLStreamHandlerFactory.class,
-		JRParameter.REPORT_FILE_RESOLVER, FileResolver.class};
+		JRParameter.REPORT_FILE_RESOLVER, FileResolver.class,
+		JRParameter.REPORT_TEMPLATES, Collection.class};
 
 
 	
@@ -171,8 +174,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 */
 	private static final Object[] BUILT_IN_PARAMETERS_MAIN = new Object[] { 
 		JRParameter.REPORT_VIRTUALIZER, JRVirtualizer.class, 
-		JRParameter.IS_IGNORE_PAGINATION, Boolean.class,
-		JRParameter.REPORT_TEMPLATES, Collection.class };
+		JRParameter.IS_IGNORE_PAGINATION, Boolean.class };
 
 	
 	/**
@@ -194,17 +196,11 @@ public class JRDesignDataset extends JRBaseDataset
 
 		try 
 		{
-			if (isMain)
-			{
-				addVariable(createPageNumberVariable());
-				addVariable(createColumnNumberVariable());
-			}
+			addVariable(createPageNumberVariable());
+			addVariable(createColumnNumberVariable());
 			addVariable(createReportCountVariable());
-			if (isMain)
-			{
-				addVariable(createPageCountVariable());
-				addVariable(createColumnCountVariable());
-			}
+			addVariable(createPageCountVariable());
+			addVariable(createColumnCountVariable());
 		}
 		catch (JRException e)
 		{
@@ -219,8 +215,8 @@ public class JRDesignDataset extends JRBaseDataset
 		variable = new JRDesignVariable();
 		variable.setName(JRVariable.PAGE_COUNT);
 		variable.setValueClass(Integer.class);
-		variable.setResetType(JRVariable.RESET_TYPE_PAGE);
-		variable.setCalculation(JRVariable.CALCULATION_COUNT);
+		variable.setResetType(ResetTypeEnum.PAGE);
+		variable.setCalculation(CalculationEnum.COUNT);
 		variable.setSystemDefined(true);
 		expression = new JRDesignExpression();
 		expression.setValueClass(Integer.class);
@@ -241,12 +237,12 @@ public class JRDesignDataset extends JRBaseDataset
 		variable.setName(JRVariable.COLUMN_NUMBER);
 		variable.setValueClass(Integer.class);
 		//variable.setResetType(JRVariable.RESET_TYPE_COLUMN);
-		variable.setResetType(JRVariable.RESET_TYPE_PAGE);
-		variable.setCalculation(JRVariable.CALCULATION_SYSTEM);
+		variable.setResetType(ResetTypeEnum.PAGE);
+		variable.setCalculation(CalculationEnum.SYSTEM);
 		variable.setSystemDefined(true);
 		expression = new JRDesignExpression();
 		expression.setValueClass(Integer.class);
-		//expression.setText("($V{COLUMN_NUMBER} != null)?(new Integer($V{COLUMN_NUMBER}.intValue() + 1)):(new Integer(1))");
+		//expression.setText("($V{COLUMN_NUMBER} != null)?(Integer.valueOf($V{COLUMN_NUMBER}.intValue() + 1)):(Integer.valueOf(1))");
 		expression.setText("new java.lang.Integer(1)");
 		variable.setInitialValueExpression(expression);
 		return variable;
@@ -258,12 +254,12 @@ public class JRDesignDataset extends JRBaseDataset
 		variable.setName(JRVariable.PAGE_NUMBER);
 		variable.setValueClass(Integer.class);
 		//variable.setResetType(JRVariable.RESET_TYPE_PAGE);
-		variable.setResetType(JRVariable.RESET_TYPE_REPORT);
-		variable.setCalculation(JRVariable.CALCULATION_SYSTEM);
+		variable.setResetType(ResetTypeEnum.REPORT);
+		variable.setCalculation(CalculationEnum.SYSTEM);
 		variable.setSystemDefined(true);
 		JRDesignExpression expression = new JRDesignExpression();
 		expression.setValueClass(Integer.class);
-		//expression.setText("($V{PAGE_NUMBER} != null)?(new Integer($V{PAGE_NUMBER}.intValue() + 1)):(new Integer(1))");
+		//expression.setText("($V{PAGE_NUMBER} != null)?(Integer.valueOf($V{PAGE_NUMBER}.intValue() + 1)):(Integer.valueOf(1))");
 		expression.setText("new java.lang.Integer(1)");
 		variable.setInitialValueExpression(expression);
 		return variable;
@@ -276,8 +272,8 @@ public class JRDesignDataset extends JRBaseDataset
 		variable = new JRDesignVariable();
 		variable.setName(JRVariable.COLUMN_COUNT);
 		variable.setValueClass(Integer.class);
-		variable.setResetType(JRVariable.RESET_TYPE_COLUMN);
-		variable.setCalculation(JRVariable.CALCULATION_COUNT);
+		variable.setResetType(ResetTypeEnum.COLUMN);
+		variable.setCalculation(CalculationEnum.COUNT);
 		variable.setSystemDefined(true);
 		expression = new JRDesignExpression();
 		expression.setValueClass(Integer.class);
@@ -296,7 +292,23 @@ public class JRDesignDataset extends JRBaseDataset
 		{
 			JRDesignParameter parameter = new JRDesignParameter();
 			parameter.setName((String) parametersArray[i++]);
-			parameter.setValueClass((Class) parametersArray[i]);
+			
+			Object parameterType = parametersArray[i];
+			if (parameterType instanceof Class)
+			{
+				parameter.setValueClass((Class) parameterType);
+			}
+			else if (parameterType instanceof String)
+			{
+				parameter.setValueClassName((String) parameterType);
+			}
+			else
+			{
+				throw new JRRuntimeException("Unknown builtin parameter type " + parameterType 
+						+ " of class " + parameterType.getClass().getName()
+						+ ". Expecint java.lang.Class or java.lang.String");
+			}
+			
 			parameter.setSystemDefined(true);
 			try
 			{
@@ -314,8 +326,8 @@ public class JRDesignDataset extends JRBaseDataset
 		JRDesignVariable variable = new JRDesignVariable();
 		variable.setName(JRVariable.REPORT_COUNT);
 		variable.setValueClass(Integer.class);
-		variable.setResetType(JRVariable.RESET_TYPE_REPORT);
-		variable.setCalculation(JRVariable.CALCULATION_COUNT);
+		variable.setResetType(ResetTypeEnum.REPORT);
+		variable.setCalculation(CalculationEnum.COUNT);
 		variable.setSystemDefined(true);
 		JRDesignExpression expression = new JRDesignExpression();
 		expression.setValueClass(Integer.class);
@@ -382,6 +394,19 @@ public class JRDesignDataset extends JRBaseDataset
 	 * @see net.sf.jasperreports.engine.JRDataset#getScriptlets()
 	 */
 	public void addScriptlet(JRScriptlet scriptlet) throws JRException
+	{
+		addScriptlet(scriptletsList.size(), scriptlet);
+	}
+
+	
+	/**
+	 * Inserts a scriptlet at the specified position into the dataset.
+	 * @param index the scriptlet position
+	 * @param scriptlet the scriptlet to insert
+	 * @throws JRException
+	 * @see net.sf.jasperreports.engine.JRDataset#getScriptlets()
+	 */
+	public void addScriptlet(int index, JRScriptlet scriptlet) throws JRException
 	{
 		if (scriptletsMap.containsKey(scriptlet.getName()))
 		{
@@ -389,17 +414,18 @@ public class JRDesignDataset extends JRBaseDataset
 		}
 
 		JRDesignParameter scriptletParameter = new JRDesignParameter();
-		scriptletParameter.setName(scriptlet.getName() + "_SCRIPTLET");
+		scriptletParameter.setName(scriptlet.getName() 
+				+ JRScriptlet.SCRIPTLET_PARAMETER_NAME_SUFFIX);
 		scriptletParameter.setValueClassName(scriptlet.getValueClassName());
 		scriptletParameter.setSystemDefined(true);
 		scriptletParameter.setForPrompting(false);
 
 		addParameter(scriptletParameter);
 
-		scriptletsList.add(scriptlet);
+		scriptletsList.add(index, scriptlet);
 		scriptletsMap.put(scriptlet.getName(), scriptlet);
 		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_SCRIPTLETS, scriptlet, scriptletsList.size() - 1);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_SCRIPTLETS, scriptlet, index);
 	}
 
 	
@@ -425,7 +451,8 @@ public class JRDesignDataset extends JRBaseDataset
 	{
 		if (scriptlet != null)
 		{
-			removeParameter(scriptlet.getName() + "_SCRIPTLET");
+			removeParameter(scriptlet.getName() 
+					+ JRScriptlet.SCRIPTLET_PARAMETER_NAME_SUFFIX);
 			int idx = scriptletsList.indexOf(scriptlet);
 			if (idx >= 0)
 			{
@@ -478,16 +505,29 @@ public class JRDesignDataset extends JRBaseDataset
 	 * @see net.sf.jasperreports.engine.JRDataset#getParameters()
 	 */
 	public void addParameter(JRParameter parameter) throws JRException
+	{
+		addParameter(parametersList.size(), parameter);
+	}
+
+	
+	/**
+	 * Inserts a parameter at the specified position into the dataset.
+	 * @param index the parameter position
+	 * @param parameter the parameter to insert
+	 * @throws JRException
+	 * @see net.sf.jasperreports.engine.JRDataset#getParameters()
+	 */
+	public void addParameter(int index, JRParameter parameter) throws JRException
 	{
 		if (parametersMap.containsKey(parameter.getName()))
 		{
 			throw new JRException("Duplicate declaration of parameter : " + parameter.getName());
 		}
 
-		parametersList.add(parameter);
+		parametersList.add(index, parameter);
 		parametersMap.put(parameter.getName(), parameter);
 		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_PARAMETERS, parameter, parametersList.size() - 1);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_PARAMETERS, parameter, index);
 	}
 
 	
@@ -616,16 +656,29 @@ public class JRDesignDataset extends JRBaseDataset
 	 * @see net.sf.jasperreports.engine.JRDataset#getFields()
 	 */
 	public void addField(JRField field) throws JRException
+	{
+		addField(fieldsList.size(), field);
+	}
+
+	
+	/**
+	 * Inserts a field at the specified position into the dataset.
+	 * @param index the field position
+	 * @param field the field to insert
+	 * @throws JRException
+	 * @see net.sf.jasperreports.engine.JRDataset#getFields()
+	 */
+	public void addField(int index, JRField field) throws JRException
 	{
 		if (fieldsMap.containsKey(field.getName()))
 		{
 			throw new JRException("Duplicate declaration of field : " + field.getName());
 		}
 
-		fieldsList.add(field);
+		fieldsList.add(index, field);
 		fieldsMap.put(field.getName(), field);
 		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_FIELDS, field, fieldsList.size() - 1);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_FIELDS, field, index);
 	}
 
 	
@@ -693,16 +746,29 @@ public class JRDesignDataset extends JRBaseDataset
 	 * @see net.sf.jasperreports.engine.JRDataset#getSortFields()
 	 */
 	public void addSortField(JRSortField sortField) throws JRException
+	{
+		addSortField(sortFieldsList.size(), sortField);
+	}
+
+	
+	/**
+	 * Inserts a sort field at specified position into the dataset.
+	 * @param index the sort field position
+	 * @param sortField the sort field to insert
+	 * @throws JRException
+	 * @see net.sf.jasperreports.engine.JRDataset#getSortFields()
+	 */
+	public void addSortField(int index, JRSortField sortField) throws JRException
 	{
 		if (sortFieldsMap.containsKey(sortField.getName()))
 		{
 			throw new JRException("Duplicate declaration of sort field : " + sortField.getName());
 		}
 
-		sortFieldsList.add(sortField);
+		sortFieldsList.add(index, sortField);
 		sortFieldsMap.put(sortField.getName(), sortField);
 		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_SORT_FIELDS, sortField, sortFieldsList.size() - 1);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_SORT_FIELDS, sortField, index);
 	}
 
 	
@@ -782,7 +848,20 @@ public class JRDesignDataset extends JRBaseDataset
 	 */
 	public void addVariable(JRDesignVariable variable) throws JRException
 	{
-		addVariable(variable, false);
+		addVariable(variablesList.size(), variable, false);
+	}
+	
+	
+	/**
+	 * Inserts a variable at specified position into the dataset.
+	 * @param index the variable position
+	 * @param variable the variable to insert
+	 * @throws JRException
+	 * @see net.sf.jasperreports.engine.JRDataset#getVariables()
+	 */
+	public void addVariable(int index, JRDesignVariable variable) throws JRException
+	{
+		addVariable(index, variable, variable.isSystemDefined());
 	}
 	
 	
@@ -795,16 +874,30 @@ public class JRDesignDataset extends JRBaseDataset
 	 * @throws JRException
 	 */
 	protected void addVariable(JRDesignVariable variable, boolean system) throws JRException
+	{
+		addVariable(variablesList.size(), variable, system);
+	}
+	
+	
+	/**
+	 * Inserts a variable at specified position into the dataset.
+	 * 
+	 * @param index the variable position
+	 * @param variable the variable to insert
+	 * @param system whether the variable should be inserted before user defined variables
+	 * or at the end of the variables list
+	 * @throws JRException
+	 */
+	protected void addVariable(int index, JRDesignVariable variable, boolean system) throws JRException
 	{
 		if (variablesMap.containsKey(variable.getName()))
 		{
 			throw new JRException("Duplicate declaration of variable : " + variable.getName());
 		}
 
-		int addedIdx;
 		if (system)
 		{
-			// add the variable vefore the first non-system variable
+			// add the variable before the first non-system variable
 			ListIterator it = variablesList.listIterator();
 			while (it.hasNext())
 			{
@@ -816,17 +909,16 @@ public class JRDesignDataset extends JRBaseDataset
 				}
 			}
 			it.add(variable);
-			addedIdx = it.previousIndex();
+			index = it.previousIndex();
 		}
 		else
 		{
-			variablesList.add(variable);
-			addedIdx = variablesList.size() - 1;
+			variablesList.add(index, variable);
 		}
 		
 		variablesMap.put(variable.getName(), variable);
 		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_VARIABLES, variable, addedIdx);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_VARIABLES, variable, index);
 	}
 
 	
@@ -904,6 +996,19 @@ public class JRDesignDataset extends JRBaseDataset
 	 * @see net.sf.jasperreports.engine.JRDataset#getGroups()
 	 */
 	public void addGroup(JRDesignGroup group) throws JRException
+	{
+		addGroup(groupsList.size(), group);
+	}
+
+	
+	/**
+	 * Inserts a group at the specified position into the dataset.
+	 * @param index the group position
+	 * @param group the group to insert
+	 * @throws JRException
+	 * @see net.sf.jasperreports.engine.JRDataset#getGroups()
+	 */
+	public void addGroup(int index, JRDesignGroup group) throws JRException
 	{
 		if (groupsMap.containsKey(group.getName()))
 		{
@@ -913,9 +1018,9 @@ public class JRDesignDataset extends JRBaseDataset
 		JRDesignVariable countVariable = new JRDesignVariable();
 		countVariable.setName(group.getName() + "_COUNT");
 		countVariable.setValueClass(Integer.class);
-		countVariable.setResetType(JRVariable.RESET_TYPE_GROUP);
+		countVariable.setResetType(ResetTypeEnum.GROUP);
 		countVariable.setResetGroup(group);
-		countVariable.setCalculation(JRVariable.CALCULATION_COUNT);
+		countVariable.setCalculation(CalculationEnum.COUNT);
 		countVariable.setSystemDefined(true);
 		JRDesignExpression expression = new JRDesignExpression();
 		expression.setValueClass(Integer.class);
@@ -930,10 +1035,10 @@ public class JRDesignDataset extends JRBaseDataset
 
 		group.setCountVariable(countVariable);
 
-		groupsList.add(group);
+		groupsList.add(index, group);
 		groupsMap.put(group.getName(), group);
 		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_GROUPS, group, groupsList.size() - 1);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_GROUPS, group, index);
 	}
 
 	
@@ -1087,10 +1192,13 @@ public class JRDesignDataset extends JRBaseDataset
 		in.defaultReadObject();
 		
 		if (sortFieldsMap == null)
+		{
 			sortFieldsMap = new HashMap();
-			
+		}
 		if (sortFieldsList == null)
+		{
 			sortFieldsList = new ArrayList();
+		}
 	}
 
 	/**
