@@ -54,7 +54,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * in <tt>JRTextElement</tt> and setters for text element attributes that can only be modified at design time.
  *
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignTextElement.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRDesignTextElement.java 3715 2010-04-08 18:08:49Z teodord $
  */
 public abstract class JRDesignTextElement extends JRDesignElement implements JRTextElement
 {
@@ -80,16 +80,16 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	 */
 	protected JRLineBox lineBox;
 
-	protected JRReportFont reportFont;
-	protected String fontName;
-	protected Boolean isBold;
-	protected Boolean isItalic;
-	protected Boolean isUnderline;
-	protected Boolean isStrikeThrough;
-	protected Integer fontSize;
-	protected String pdfFontName;
-	protected String pdfEncoding;
-	protected Boolean isPdfEmbedded;
+	protected JRReportFont reportFont = null;
+	protected String fontName = null;
+	protected Boolean isBold = null;
+	protected Boolean isItalic = null;
+	protected Boolean isUnderline = null;
+	protected Boolean isStrikeThrough = null;
+	protected Integer fontSize = null;
+	protected String pdfFontName = null;
+	protected String pdfEncoding = null;
+	protected Boolean isPdfEmbedded = null;
 
 
 	/**
@@ -1308,67 +1308,67 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	/**
 	 * @deprecated
 	 */
-	private Byte border;
+	private Byte border = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte topBorder;
+	private Byte topBorder = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte leftBorder;
+	private Byte leftBorder = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte bottomBorder;
+	private Byte bottomBorder = null;
 	/**
 	 * @deprecated
 	 */
-	private Byte rightBorder;
+	private Byte rightBorder = null;
 	/**
 	 * @deprecated
 	 */
-	private Color borderColor;
+	private Color borderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Color topBorderColor;
+	private Color topBorderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Color leftBorderColor;
+	private Color leftBorderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Color bottomBorderColor;
+	private Color bottomBorderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Color rightBorderColor;
+	private Color rightBorderColor = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer padding;
+	private Integer padding = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer topPadding;
+	private Integer topPadding = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer leftPadding;
+	private Integer leftPadding = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer bottomPadding;
+	private Integer bottomPadding = null;
 	/**
 	 * @deprecated
 	 */
-	private Integer rightPadding;
+	private Integer rightPadding = null;
 	/**
 	 * @deprecated
 	 */
-	private Boolean isStyledText;
+	private Boolean isStyledText = null;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
