@@ -49,7 +49,7 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignTextField.java 3941 2010-08-20 10:55:10Z teodord $
+ * @version $Id: JRDesignTextField.java 3715 2010-04-08 18:08:49Z teodord $
  */
 public class JRDesignTextField extends JRDesignTextElement implements JRTextField
 {
@@ -78,10 +78,10 @@ public class JRDesignTextField extends JRDesignTextElement implements JRTextFiel
 	/**
 	 *
 	 */
-	protected boolean isStretchWithOverflow;
+	protected boolean isStretchWithOverflow = false;
 	protected EvaluationTimeEnum evaluationTimeValue = EvaluationTimeEnum.NOW;
-	protected String pattern;
-	protected Boolean isBlankWhenNull;
+	protected String pattern = null;
+	protected Boolean isBlankWhenNull = null;
 	protected String linkType;
 	protected String linkTarget;
 	private List hyperlinkParameters;
@@ -89,12 +89,12 @@ public class JRDesignTextField extends JRDesignTextElement implements JRTextFiel
 	/**
 	 *
 	 */
-	protected JRGroup evaluationGroup;
-	protected JRExpression expression;
-	protected JRExpression anchorNameExpression;
-	protected JRExpression hyperlinkReferenceExpression;
-	protected JRExpression hyperlinkAnchorExpression;
-	protected JRExpression hyperlinkPageExpression;
+	protected JRGroup evaluationGroup = null;
+	protected JRExpression expression = null;
+	protected JRExpression anchorNameExpression = null;
+	protected JRExpression hyperlinkReferenceExpression = null;
+	protected JRExpression hyperlinkAnchorExpression = null;
+	protected JRExpression hyperlinkPageExpression = null;
 	private JRExpression hyperlinkTooltipExpression;
 
 	/**
