@@ -37,19 +37,19 @@ import java.util.List;
 import java.util.Map;
 
 import net.sf.jasperreports.engine.JRBoxContainer;
-import net.sf.jasperreports.engine.JRElement;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintFrame;
 import net.sf.jasperreports.engine.JRPrintPage;
 import net.sf.jasperreports.engine.base.JRBasePrintFrame;
+import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 
 /**
  * Utility class used by grid exporters to create a grid for page layout.
  *
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRGridLayout.java 3153 2009-10-23 19:03:44Z teodord $
+ * @version $Id: JRGridLayout.java 3875 2010-07-14 09:58:21Z teodord $
  */
 public class JRGridLayout
 {
@@ -266,7 +266,7 @@ public class JRGridLayout
 
 				if(hasLeftMargin)
 				{
-					xCutsList.remove(new Integer(0));
+					xCutsList.remove(Integer.valueOf(0));
 				}
 			}
 
@@ -274,11 +274,11 @@ public class JRGridLayout
 
 			if(hasTopMargin)
 			{
-				yCutsList.remove(new Integer(0));
+				yCutsList.remove(Integer.valueOf(0));
 			}
 			if(hasBottomMargin)
 			{
-				yCutsList.remove(new Integer(height));
+				yCutsList.remove(Integer.valueOf(height));
 			}
 		}
 
@@ -339,9 +339,9 @@ public class JRGridLayout
 
 				yCuts.addYCuts(element, elementOffsetY);
 				
-				if (nature.isDeep() && element instanceof JRPrintFrame)
+				JRPrintFrame frame = element instanceof JRPrintFrame ? (JRPrintFrame)element : null;
+				if (frame != null && nature.isDeep(frame))
 				{
-					JRPrintFrame frame = (JRPrintFrame) element;
 					createCuts(
 						wrapper.getWrappers(),
 						element.getX() + elementOffsetX + frame.getLineBox().getLeftPadding().intValue(),
@@ -408,10 +408,9 @@ public class JRGridLayout
 
 				if (!isOverlap(row1, col1, row2, col2))
 				{
-					if (nature.isDeep() && element instanceof JRPrintFrame)
+					JRPrintFrame frame = element instanceof JRPrintFrame ? (JRPrintFrame)element : null;
+					if (frame != null && nature.isDeep(frame))
 					{
-						JRPrintFrame frame = (JRPrintFrame) element;
-						
 						setGridElements(
 							wrapper.getWrappers(),
 							x + frame.getLineBox().getLeftPadding().intValue(),
@@ -573,7 +572,7 @@ public class JRGridLayout
 
 	protected void setFrameCellsStyle(JRPrintFrame frame, int row1, int col1, int row2, int col2)
 	{
-		Color backcolor = frame.getMode() == JRElement.MODE_OPAQUE ? frame.getBackcolor() : null;
+		Color backcolor = frame.getModeValue() == ModeEnum.OPAQUE ? frame.getBackcolor() : null;
 
 		for (int row = row1; row < row2; row++)
 		{
@@ -583,7 +582,7 @@ public class JRGridLayout
 
 				if (cell.getBackcolor() == null)
 				{
-					if (frame.getMode() == JRElement.MODE_OPAQUE)
+					if (frame.getModeValue() == ModeEnum.OPAQUE)
 					{
 						cell.setBackcolor(backcolor);
 					}
