@@ -52,7 +52,7 @@ import com.lowagie.text.pdf.PdfWriter;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPdfExporterTagHelper.java 3941 2010-08-20 10:55:10Z teodord $
+ * @version $Id: JRPdfExporterTagHelper.java 3668 2010-03-31 15:23:49Z shertage $
  */
 public class JRPdfExporterTagHelper
 {
@@ -69,19 +69,19 @@ public class JRPdfExporterTagHelper
 	public static final String TAG_END = "end";
 	public static final String TAG_FULL = "full";
 	
-	protected JRPdfExporter exporter;
+	protected JRPdfExporter exporter = null;
 
-	protected PdfContentByte pdfContentByte;
-	protected PdfWriter pdfWriter;
+	protected PdfContentByte pdfContentByte = null;
+	protected PdfWriter pdfWriter = null;
 
-	protected PdfStructureElement allTag;
-	protected Stack tagStack;
+	protected PdfStructureElement allTag = null;
+	protected Stack tagStack = null;
 	protected boolean isTagEmpty = true;
 	protected int crtCrosstabRowY = -1;
-	protected int crosstabFrameDepth;
-	protected boolean isDataCellPrinted;
+	protected int crosstabFrameDepth = 0;
+	protected boolean isDataCellPrinted = false;
 
-	protected boolean isTagged;
+	protected boolean isTagged = false;
 
 	/**
 	 *
