@@ -35,7 +35,6 @@ import java.util.List;
 import java.util.StringTokenizer;
 
 import net.sf.jasperreports.engine.JRAbstractExporter;
-import net.sf.jasperreports.engine.JRAlignment;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExporterParameter;
 import net.sf.jasperreports.engine.JRPrintFrame;
@@ -64,7 +63,7 @@ import net.sf.jasperreports.engine.util.JRStyledText;
  *
  * @see JRExporterParameter
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRTextExporter.java 3223 2009-12-03 12:50:21Z teodord $
+ * @version $Id: JRTextExporter.java 3678 2010-04-02 12:13:06Z shertage $
  */
 public class JRTextExporter extends JRAbstractExporter
 {
@@ -113,12 +112,14 @@ public class JRTextExporter extends JRAbstractExporter
 				);
 
 		betweenPagesText = (String) parameters.get(JRTextExporterParameter.BETWEEN_PAGES_TEXT);
-		if (betweenPagesText == null) {
+		if (betweenPagesText == null) 
+		{
 			betweenPagesText = systemLineSeparator + systemLineSeparator;
 		}
 
 		lineSeparator = (String) parameters.get(JRTextExporterParameter.LINE_SEPARATOR);
-		if (lineSeparator == null) {
+		if (lineSeparator == null) 
+		{
 			lineSeparator = systemLineSeparator;
 		}
 
@@ -417,10 +418,14 @@ public class JRTextExporter extends JRAbstractExporter
 
 		// if the space is too small, the element will not be rendered
 		if (rowSpan <= 0 || colSpan <= 0)
+		{
 			return;
+		}
 
 		if (allText != null && allText.length() == 0)
+		{
 			return;
+		}
 
 		// uses an array of string buffers, since the maximum number of rows is already calculated
 		StringBuffer[] rows = new StringBuffer[rowSpan];
@@ -439,7 +444,9 @@ public class JRTextExporter extends JRAbstractExporter
 				rows[rowIndex].append("");
 				rowIndex++;
 				if(rowIndex == rowSpan || !lfTokenizer.hasMoreTokens())
+				{
 					break label;
+				}
 				rowPosition = 0;
 				rows[rowIndex] = new StringBuffer();
 				line = lfTokenizer.nextToken();
@@ -462,7 +469,9 @@ public class JRTextExporter extends JRAbstractExporter
 					rows[rowIndex].append("");
 					rowIndex++;
 					if(rowIndex == rowSpan)
+					{
 						break label;
+					}
 					rowPosition = 0;
 					rows[rowIndex] = new StringBuffer();
 					//if this is the last empty line:
@@ -489,17 +498,22 @@ public class JRTextExporter extends JRAbstractExporter
 						word = word.substring(colSpan - rowPosition, word.length());
 						rowIndex++;
 						if(rowIndex == rowSpan)
+						{
 							break label;
+						}
 						rowPosition = 0;
 						rows[rowIndex] = new StringBuffer();
 					}
 	
 					// situation: word is larger than remaining space on the current line
 					// in this case, go to the next line
-					if (rowPosition + word.length() > colSpan) {
+					if (rowPosition + word.length() > colSpan) 
+					{
 						rowIndex++;
 						if (rowIndex == rowSpan)
+						{
 							break label;
+						}
 						rowPosition = 0;
 						rows[rowIndex] = new StringBuffer();
 					}
@@ -507,8 +521,9 @@ public class JRTextExporter extends JRAbstractExporter
 					// situation: the word is actually a space and it situated at the beginning of a new line
 					// in this case, it is removed
 					if (rowIndex > 0 && rowPosition == 0 && word.equals(" "))
+					{
 						continue;
-	
+					}
 					// situation: the word is small enough to fit in the current line
 					// in this case just add the word and increment the cursor position
 					rows[rowIndex].append(word);
@@ -518,7 +533,9 @@ public class JRTextExporter extends JRAbstractExporter
 	
 				rowIndex++;
 				if(rowIndex == rowSpan)
+				{
 					break;
+				}
 				rowPosition = 0;
 				rows[rowIndex] = new StringBuffer();
 			}
@@ -527,27 +544,52 @@ public class JRTextExporter extends JRAbstractExporter
 		int colOffset = 0;
 		int rowOffset = 0;
 
-		if (element.getVerticalAlignment() == JRAlignment.VERTICAL_ALIGN_BOTTOM)
-			rowOffset = rowSpan - rowIndex;
-		if (element.getVerticalAlignment() == JRAlignment.VERTICAL_ALIGN_MIDDLE)
-			rowOffset = (rowSpan - rowIndex) / 2;
+		switch (element.getVerticalAlignmentValue())
+		{
+			case BOTTOM :
+			{
+				rowOffset = rowSpan - rowIndex;
+				break;
+			}
+			case MIDDLE :
+			{
+				rowOffset = (rowSpan - rowIndex) / 2;
+				break;
+			}
+		}
 
 		for (int i = 0; i < rowIndex; i++) {
 			String line = rows[i].toString();
 			int pos = line.length() - 1;
 			while (pos >= 0 && line.charAt(pos) == ' ')
+			{
 				pos--;
+			}
 			line = line.substring(0, pos + 1);
-			if (element.getHorizontalAlignment() == JRAlignment.HORIZONTAL_ALIGN_RIGHT)
-				colOffset = colSpan - line.length();
-			if (element.getHorizontalAlignment() == JRAlignment.HORIZONTAL_ALIGN_CENTER)
-				colOffset = (colSpan - line.length()) / 2;
-
-			// if text is justified, there is no offset, but the line text is modified
-			// the last line in the paragraph is not justified.
-			if (element.getHorizontalAlignment() == JRAlignment.HORIZONTAL_ALIGN_JUSTIFIED)
-				if (i < rowIndex -1)
-					line = justifyText(line, colSpan);
+			switch (element.getHorizontalAlignmentValue())
+			{
+				case RIGHT :
+				{
+					colOffset = colSpan - line.length();
+					break;
+				}
+				case CENTER :
+				{
+					colOffset = (colSpan - line.length()) / 2;
+					break;
+				}
+	
+				// if text is justified, there is no offset, but the line text is modified
+				// the last line in the paragraph is not justified.
+				case JUSTIFIED :
+				{
+					if (i < rowIndex -1)
+					{
+						line = justifyText(line, colSpan);
+					}
+					break;
+				}
+			}
 
 			char[] chars = line.toCharArray();
 			System.arraycopy(chars, 0, pageData[row + rowOffset + i], col + colOffset, chars.length);
@@ -565,12 +607,16 @@ public class JRTextExporter extends JRAbstractExporter
 		StringTokenizer t = new StringTokenizer(s, " ");
 		int tokenCount = t.countTokens();
 		if (tokenCount <= 1)
+		{
 			return s;
+		}
 
 		String[] words = new String[tokenCount];
 		int i = 0;
 		while (t.hasMoreTokens())
+		{
 			words[i++] = t.nextToken();
+		}
 
 		int emptySpace = width - s.length() + (words.length - 1);
 		int spaceCount = emptySpace / (words.length - 1);
@@ -584,7 +630,9 @@ public class JRTextExporter extends JRAbstractExporter
 			justified.append(words[i]);
 			justified.append(spaces);
 			if (i < remainingSpace)
+			{
 				justified.append(' ');
+			}
 		}
 		justified.append(words[words.length-1]);
 
