@@ -37,7 +37,7 @@ import net.sf.jasperreports.engine.util.JRProperties;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRXlsAbstractExporterNature.java 4015 2010-10-27 10:44:19Z teodord $
+ * @version $Id: JRXlsAbstractExporterNature.java 3875 2010-07-14 09:58:21Z teodord $
  */
 public class JRXlsAbstractExporterNature implements ExporterNature
 {
@@ -45,9 +45,9 @@ public class JRXlsAbstractExporterNature implements ExporterNature
 	public static final String PROPERTY_BREAK_BEFORE_ROW = JRProperties.PROPERTY_PREFIX + "export.xls.break.before.row";
 	public static final String PROPERTY_BREAK_AFTER_ROW = JRProperties.PROPERTY_PREFIX + "export.xls.break.after.row";
 
-	protected ExporterFilter filter;
-	protected boolean isIgnoreGraphics;
-	protected boolean isIgnorePageMargins;
+	protected ExporterFilter filter = null;
+	protected boolean isIgnoreGraphics = false;
+	protected boolean isIgnorePageMargins = false;
 
 	/**
 	 * 
@@ -76,7 +76,7 @@ public class JRXlsAbstractExporterNature implements ExporterNature
 		if (element instanceof JRGenericPrintElement)
 		{
 			JRGenericPrintElement genericElement = (JRGenericPrintElement) element;
-			GenericElementHtmlHandler handler = (GenericElementHtmlHandler) //FIXMENOW html handler???
+			GenericElementHtmlHandler handler = (GenericElementHtmlHandler) 
 			GenericElementHandlerEnviroment.getHandler(
 					genericElement.getGenericType(), JRHtmlExporter.HTML_EXPORTER_KEY);
 			if (handler == null || !handler.toExport(genericElement))
