@@ -40,7 +40,12 @@ import java.util.LinkedList;
 
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRPrintElement;
+import net.sf.jasperreports.engine.JRPrintEllipse;
 import net.sf.jasperreports.engine.JRPrintFrame;
+import net.sf.jasperreports.engine.JRPrintImage;
+import net.sf.jasperreports.engine.JRPrintLine;
+import net.sf.jasperreports.engine.JRPrintRectangle;
+import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.export.ExporterFilter;
 import net.sf.jasperreports.engine.export.TextRenderer;
 import net.sf.jasperreports.engine.type.ModeEnum;
@@ -48,9 +53,9 @@ import net.sf.jasperreports.engine.type.ModeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: FrameDrawer.java 3991 2010-10-12 20:10:55Z lucianc $
+ * @version $Id: FrameDrawer.java 3420 2010-02-18 09:17:47Z teodord $
  */
-public class FrameDrawer extends ElementDrawer<JRPrintFrame>
+public class FrameDrawer extends ElementDrawer
 {
 	/**
 	 *
@@ -60,16 +65,21 @@ public class FrameDrawer extends ElementDrawer<JRPrintFrame>
 	/**
 	 *
 	 */
-	private ExporterFilter filter;
-	private Graphics2D grx;
-	private LinkedList<Offset> elementOffsetStack = new LinkedList<Offset>();
-	private Offset elementOffset;
-	private boolean isClip;
+	private ExporterFilter filter = null;
+	private Graphics2D grx = null;
+	private LinkedList elementOffsetStack = new LinkedList();
+	private int elementOffsetX = 0;
+	private int elementOffsetY = 0;
+	private boolean isClip = false;
 	
 	/**
 	 *
 	 */
-	private PrintDrawVisitor drawVisitor;
+	private LineDrawer lineDrawer = null;
+	private RectangleDrawer rectangleDrawer = null;
+	private EllipseDrawer ellipseDrawer = null;
+	private ImageDrawer imageDrawer = null;
+	private TextDrawer textDrawer = null;
 
 	
 	/**
@@ -82,9 +92,11 @@ public class FrameDrawer extends ElementDrawer<JRPrintFrame>
 	{
 		this.filter = filter;
 		
-		drawVisitor = new PrintDrawVisitor();
-		drawVisitor.setTextDrawer(new TextDrawer(textRenderer));
-		drawVisitor.setFrameDrawer(this);
+		lineDrawer = new LineDrawer();
+		rectangleDrawer = new RectangleDrawer();
+		ellipseDrawer = new EllipseDrawer();
+		imageDrawer = new ImageDrawer();
+		textDrawer = new TextDrawer(textRenderer);
 	}
 	
 	
@@ -100,9 +112,11 @@ public class FrameDrawer extends ElementDrawer<JRPrintFrame>
 	/**
 	 *
 	 */
-	public void draw(Graphics2D grx, JRPrintFrame frame, int offsetX, int offsetY) throws JRException
+	public void draw(Graphics2D grx, JRPrintElement element, int offsetX, int offsetY) throws JRException
 	{
-		setGraphics(grx);
+		this.grx = grx;
+		
+		JRPrintFrame frame = (JRPrintFrame)element;
 		
 		Shape oldClipShape = null;
 		if (isClip)
@@ -155,7 +169,7 @@ public class FrameDrawer extends ElementDrawer<JRPrintFrame>
 	 */
 	public void draw(Graphics2D grx, Collection elements, int offsetX, int offsetY) throws JRException
 	{
-		setGraphics(grx);
+		this.grx = grx;
 		
 		setElementOffsets(offsetX, offsetY);
 		try
@@ -169,13 +183,6 @@ public class FrameDrawer extends ElementDrawer<JRPrintFrame>
 	}
 
 
-	protected void setGraphics(Graphics2D grx)
-	{
-		this.grx = grx;
-		drawVisitor.setGraphics2D(grx);
-	}
-
-
 	/**
 	 *
 	 */
@@ -191,8 +198,8 @@ public class FrameDrawer extends ElementDrawer<JRPrintFrame>
 				if (
 					(filter != null && !filter.isToExport(element))
 					|| !clipArea.intersects(
-						element.getX() + elementOffset.getX() - ELEMENT_RECTANGLE_PADDING, 
-						element.getY() + elementOffset.getY() - ELEMENT_RECTANGLE_PADDING, 
+						element.getX() + getOffsetX() - ELEMENT_RECTANGLE_PADDING, 
+						element.getY() + getOffsetY() - ELEMENT_RECTANGLE_PADDING, 
 						element.getWidth() + 2 * ELEMENT_RECTANGLE_PADDING, 
 						element.getHeight() + 2 * ELEMENT_RECTANGLE_PADDING)
 					)
@@ -200,7 +207,30 @@ public class FrameDrawer extends ElementDrawer<JRPrintFrame>
 					continue;
 				}
 				
-				element.accept(drawVisitor, elementOffset);
+				if (element instanceof JRPrintLine)
+				{
+					lineDrawer.draw(grx, element, getOffsetX(), getOffsetY());
+				}
+				else if (element instanceof JRPrintRectangle)
+				{
+					rectangleDrawer.draw(grx, element, getOffsetX(), getOffsetY());
+				}
+				else if (element instanceof JRPrintEllipse)
+				{
+					ellipseDrawer.draw(grx, element, getOffsetX(), getOffsetY());
+				}
+				else if (element instanceof JRPrintImage)
+				{
+					imageDrawer.draw(grx, element, getOffsetX(), getOffsetY());
+				}
+				else if (element instanceof JRPrintText)
+				{
+					textDrawer.draw(grx, element, getOffsetX(), getOffsetY());
+				}
+				else if (element instanceof JRPrintFrame)
+				{
+					this.draw(grx, element, getOffsetX(), getOffsetY());
+				}
 			}
 		}
 	}
@@ -223,9 +253,10 @@ public class FrameDrawer extends ElementDrawer<JRPrintFrame>
 	 */
 	private void setElementOffsets(int offsetX, int offsetY)
 	{
-		elementOffsetStack.addLast(elementOffset);
+		elementOffsetStack.addLast(new int[]{elementOffsetX, elementOffsetY});
 		
-		elementOffset = new Offset(offsetX, offsetY);
+		elementOffsetX = offsetX;
+		elementOffsetY = offsetY;
 	}
 
 	
@@ -234,7 +265,27 @@ public class FrameDrawer extends ElementDrawer<JRPrintFrame>
 	 */
 	private void restoreElementOffsets()
 	{
-		elementOffset = elementOffsetStack.removeLast();
+		int[] offsets = (int[]) elementOffsetStack.removeLast();
+		elementOffsetX = offsets[0];
+		elementOffsetY = offsets[1];
+	}
+
+	
+	/**
+	 *
+	 */
+	private int getOffsetX()
+	{
+		return elementOffsetX;
+	}
+
+
+	/**
+	 *
+	 */
+	private int getOffsetY()
+	{
+		return elementOffsetY;
 	}
 
 
