@@ -38,6 +38,7 @@ import java.awt.geom.Dimension2D;
 
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRImageRenderer;
+import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.JRRenderable;
 import net.sf.jasperreports.engine.type.ModeEnum;
@@ -45,16 +46,18 @@ import net.sf.jasperreports.engine.type.ModeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ImageDrawer.java 3991 2010-10-12 20:10:55Z lucianc $
+ * @version $Id: ImageDrawer.java 3499 2010-03-03 15:35:34Z shertage $
  */
-public class ImageDrawer extends ElementDrawer<JRPrintImage>
+public class ImageDrawer extends ElementDrawer
 {
 
 	/**
 	 *
 	 */
-	public void draw(Graphics2D grx, JRPrintImage printImage, int offsetX, int offsetY) throws JRException
+	public void draw(Graphics2D grx, JRPrintElement element, int offsetX, int offsetY) throws JRException
 	{
+		JRPrintImage printImage = (JRPrintImage)element;
+		
 		if (printImage.getModeValue() == ModeEnum.OPAQUE)
 		{
 			grx.setColor(printImage.getBackcolor());
