@@ -36,6 +36,7 @@ import java.awt.Graphics2D;
 import java.awt.Stroke;
 import java.awt.geom.AffineTransform;
 
+import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintRectangle;
 import net.sf.jasperreports.engine.export.legacy.BorderOffset;
 import net.sf.jasperreports.engine.type.LineStyleEnum;
@@ -45,16 +46,18 @@ import net.sf.jasperreports.engine.util.JRPenUtil;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: RectangleDrawer.java 3991 2010-10-12 20:10:55Z lucianc $
+ * @version $Id: RectangleDrawer.java 3467 2010-02-23 13:11:13Z teodord $
  */
-public class RectangleDrawer extends ElementDrawer<JRPrintRectangle>
+public class RectangleDrawer extends ElementDrawer
 {
 
 	/**
 	 *
 	 */
-	public void draw(Graphics2D grx, JRPrintRectangle rectangle, int offsetX, int offsetY)
+	public void draw(Graphics2D grx, JRPrintElement element, int offsetX, int offsetY)
 	{
+		JRPrintRectangle rectangle = (JRPrintRectangle)element;
+		
 		int width = rectangle.getWidth();
 		int height = rectangle.getHeight();
 		
