@@ -35,7 +35,7 @@ import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ParagraphStyle.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: ParagraphStyle.java 3496 2010-03-03 11:39:03Z teodord $
  */
 public class ParagraphStyle extends Style
 {
@@ -62,9 +62,9 @@ public class ParagraphStyle extends Style
 	protected static final String ROTATION_ALIGN_CENTER = "center";
 	protected static final String ROTATION_ALIGN_BOTTOM = "bottom";
 
-	private String verticalAlignment;
-	private String horizontalAlignment;
-	private String runDirection;
+	private String verticalAlignment = null;
+	private String horizontalAlignment = null;
+	private String runDirection = null;
 	private String textRotation = "0";
 
 	/**
