@@ -38,7 +38,7 @@ import net.sf.jasperreports.engine.util.JRColorUtil;
 
 /**
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: DocxCellHelper.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: DocxCellHelper.java 3496 2010-03-03 11:39:03Z teodord $
  */
 public class DocxCellHelper extends BaseHelper
 {
@@ -52,7 +52,7 @@ public class DocxCellHelper extends BaseHelper
 	/**
 	 *
 	 */
-	private DocxBorderHelper borderHelper;
+	private DocxBorderHelper borderHelper = null;
 	
 	/**
 	 *
