@@ -33,7 +33,7 @@ import net.sf.jasperreports.engine.type.LineSpacingEnum;
 
 /**
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: DocxParagraphHelper.java 3941 2010-08-20 10:55:10Z teodord $
+ * @version $Id: DocxParagraphHelper.java 3817 2010-05-20 11:25:13Z teodord $
  */
 public class DocxParagraphHelper extends BaseHelper
 {
@@ -50,7 +50,7 @@ public class DocxParagraphHelper extends BaseHelper
 	/**
 	 *
 	 */
-	private boolean pageBreak;
+	private boolean pageBreak = false;
 
 	/**
 	 *
