@@ -36,15 +36,15 @@ import net.sf.jasperreports.engine.util.JRDataUtils;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: DocxStyleHelper.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: DocxStyleHelper.java 3817 2010-05-20 11:25:13Z teodord $
  */
 public class DocxStyleHelper extends BaseHelper
 {
 	/**
 	 * 
 	 */
-	private DocxParagraphHelper paragraphHelper;
-	private DocxRunHelper runHelper;
+	private DocxParagraphHelper paragraphHelper = null;
+	private DocxRunHelper runHelper = null;
 	
 	/**
 	 * 
