@@ -41,15 +41,10 @@ import java.util.Locale;
 import java.util.Map;
 
 import net.sf.jasperreports.engine.JRAbstractExporter;
-import net.sf.jasperreports.engine.JRAlignment;
-import net.sf.jasperreports.engine.JRElement;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExporterParameter;
 import net.sf.jasperreports.engine.JRGenericPrintElement;
-import net.sf.jasperreports.engine.JRHyperlink;
-import net.sf.jasperreports.engine.JRImage;
 import net.sf.jasperreports.engine.JRImageRenderer;
-import net.sf.jasperreports.engine.JRLine;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRPrintElement;
@@ -79,6 +74,8 @@ import net.sf.jasperreports.engine.export.JRGridLayout;
 import net.sf.jasperreports.engine.export.JRHyperlinkProducer;
 import net.sf.jasperreports.engine.export.OccupiedGridCell;
 import net.sf.jasperreports.engine.export.zip.FileBufferedZipEntry;
+import net.sf.jasperreports.engine.type.LineDirectionEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
@@ -92,7 +89,7 @@ import org.apache.commons.logging.LogFactory;
  * Exports a JasperReports document to DOCX format. It has character output type and exports the document to a
  * grid-based layout.
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: JRDocxExporter.java 3165 2009-10-26 14:58:08Z teodord $
+ * @version $Id: JRDocxExporter.java 3816 2010-05-20 09:30:33Z teodord $
  */
 public class JRDocxExporter extends JRAbstractExporter
 {
@@ -381,7 +378,7 @@ public class JRDocxExporter extends JRAbstractExporter
 						new JRWrappingSvgRenderer(
 							renderer,
 							new Dimension(image.getWidth(), image.getHeight()),
-							JRElement.MODE_OPAQUE == image.getMode() ? image.getBackcolor() : null
+							ModeEnum.OPAQUE == image.getModeValue() ? image.getBackcolor() : null
 							);
 				}
 
@@ -429,7 +426,7 @@ public class JRDocxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected void exportPage(JRPrintPage page) throws JRException, IOException
+	protected void exportPage(JRPrintPage page) throws JRException
 	{
 		startPage = true;
 		JRGridLayout layout =
@@ -469,7 +466,6 @@ public class JRDocxExporter extends JRAbstractExporter
 			new DocxTableHelper(
 				docWriter, 
 				xCuts,
-				runHelper,
 				frameIndex == null && (reportIndex != 0 || pageIndex != startPageIndex)
 				);
 
@@ -579,10 +575,10 @@ public class JRDocxExporter extends JRAbstractExporter
 				}
 			}
 
-			if (emptyCellColSpan > 0)
-			{
-				//writeEmptyCell(tableHelper, null, emptyCellColSpan, emptyCellWidth, rowHeight);
-			}
+//			if (emptyCellColSpan > 0)
+//			{
+//				//writeEmptyCell(tableHelper, null, emptyCellColSpan, emptyCellWidth, rowHeight);
+//			}
 
 			tableHelper.exportRowFooter();
 		}
@@ -605,7 +601,7 @@ public class JRDocxExporter extends JRAbstractExporter
 		float ratio = line.getWidth() / line.getHeight();
 		if (ratio > 1)
 		{
-			if (line.getDirection() == JRLine.DIRECTION_TOP_DOWN)
+			if (line.getDirectionValue() == LineDirectionEnum.TOP_DOWN)
 			{
 				pen = box.getTopPen();
 			}
@@ -616,7 +612,7 @@ public class JRDocxExporter extends JRAbstractExporter
 		}
 		else
 		{
-			if (line.getDirection() == JRLine.DIRECTION_TOP_DOWN)
+			if (line.getDirectionValue() == LineDirectionEnum.TOP_DOWN)
 			{
 				pen = box.getLeftPen();
 			}
@@ -626,7 +622,7 @@ public class JRDocxExporter extends JRAbstractExporter
 			}
 		}
 		pen.setLineColor(line.getLinePen().getLineColor());
-		pen.setLineStyle(line.getLinePen().getLineStyle());
+		pen.setLineStyle(line.getLinePen().getLineStyleValue());
 		pen.setLineWidth(line.getLinePen().getLineWidth());
 
 		gridCell.setBox(box);//CAUTION: only some exporters set the cell box
@@ -645,7 +641,7 @@ public class JRDocxExporter extends JRAbstractExporter
 		JRLineBox box = new JRBaseLineBox(null);
 		JRPen pen = box.getPen();
 		pen.setLineColor(rectangle.getLinePen().getLineColor());
-		pen.setLineStyle(rectangle.getLinePen().getLineStyle());
+		pen.setLineStyle(rectangle.getLinePen().getLineStyleValue());
 		pen.setLineWidth(rectangle.getLinePen().getLineWidth());
 
 		gridCell.setBox(box);//CAUTION: only some exporters set the cell box
@@ -664,7 +660,7 @@ public class JRDocxExporter extends JRAbstractExporter
 		JRLineBox box = new JRBaseLineBox(null);
 		JRPen pen = box.getPen();
 		pen.setLineColor(ellipse.getLinePen().getLineColor());
-		pen.setLineStyle(ellipse.getLinePen().getLineStyle());
+		pen.setLineStyle(ellipse.getLinePen().getLineStyleValue());
 		pen.setLineWidth(ellipse.getLinePen().getLineWidth());
 
 		gridCell.setBox(box);//CAUTION: only some exporters set the cell box
@@ -697,11 +693,6 @@ public class JRDocxExporter extends JRAbstractExporter
 //			styleBuffer.append("word-wrap: break-word; ");
 //		}
 
-//		if (text.getLineSpacing() != JRTextElement.LINE_SPACING_SINGLE)
-//		{
-//			styleBuffer.append("line-height: " + text.getLineSpacingFactor() + "; ");
-//		}
-
 //		if (styleBuffer.length() > 0)
 //		{
 //			writer.write(" style=\"");
@@ -784,7 +775,7 @@ public class JRDocxExporter extends JRAbstractExporter
 
 		tableHelper.getCellHelper().exportHeader(image, gridCell);
 
-		docHelper.write("<w:p>");
+		docHelper.write("<w:p>");//FIXMEDOCX why is this here and not further down?
 
 		JRRenderable renderer = image.getRenderer();
 
@@ -798,7 +789,7 @@ public class JRDocxExporter extends JRAbstractExporter
 			{
 				// Non-lazy image renderers are all asked for their image data at some point.
 				// Better to test and replace the renderer now, in case of lazy load error.
-				renderer = JRImageRenderer.getOnErrorRendererForImageData(renderer, image.getOnErrorType());
+				renderer = JRImageRenderer.getOnErrorRendererForImageData(renderer, image.getOnErrorTypeValue());
 			}
 		}
 		else
@@ -816,7 +807,7 @@ public class JRDocxExporter extends JRAbstractExporter
 
 			// Image load might fail.
 			JRRenderable tmpRenderer =
-				JRImageRenderer.getOnErrorRendererForDimension(renderer, image.getOnErrorType());
+				JRImageRenderer.getOnErrorRendererForDimension(renderer, image.getOnErrorTypeValue());
 			Dimension2D dimension = tmpRenderer == null ? null : tmpRenderer.getDimension();
 			// If renderer was replaced, ignore image dimension.
 			if (tmpRenderer == renderer && dimension != null)
@@ -830,33 +821,33 @@ public class JRDocxExporter extends JRAbstractExporter
 			double cropBottom = 0;
 			double cropRight = 0;
 			
-			switch (image.getScaleImage())
+			switch (image.getScaleImageValue())
 			{
-				case JRImage.SCALE_IMAGE_FILL_FRAME :
+				case FILL_FRAME :
 				{
 					width = availableImageWidth;
 					height = availableImageHeight;
 					break;
 				}
-				case JRImage.SCALE_IMAGE_CLIP :
+				case CLIP :
 				{
 					if (normalWidth > availableImageWidth)
 					{
-						switch (image.getHorizontalAlignment())
+						switch (image.getHorizontalAlignmentValue())
 						{
-							case JRAlignment.HORIZONTAL_ALIGN_RIGHT :
+							case RIGHT :
 							{
 								cropLeft = 65536 * (normalWidth - availableImageWidth) / normalWidth;
 								cropRight = 0;
 								break;
 							}
-							case JRAlignment.HORIZONTAL_ALIGN_CENTER :
+							case CENTER :
 							{
 								cropLeft = 65536 * (- availableImageWidth + normalWidth) / normalWidth / 2;
 								cropRight = cropLeft;
 								break;
 							}
-							case JRAlignment.HORIZONTAL_ALIGN_LEFT :
+							case LEFT :
 							default :
 							{
 								cropLeft = 0;
@@ -875,21 +866,21 @@ public class JRDocxExporter extends JRAbstractExporter
 
 					if (normalHeight > availableImageHeight)
 					{
-						switch (image.getVerticalAlignment())
+						switch (image.getVerticalAlignmentValue())
 						{
-							case JRAlignment.VERTICAL_ALIGN_TOP :
+							case TOP :
 							{
 								cropTop = 0;
 								cropBottom = 65536 * (normalHeight - availableImageHeight) / normalHeight;
 								break;
 							}
-							case JRAlignment.VERTICAL_ALIGN_MIDDLE :
+							case MIDDLE :
 							{
 								cropTop = 65536 * (normalHeight - availableImageHeight) / normalHeight / 2;
 								cropBottom = cropTop;
 								break;
 							}
-							case JRAlignment.VERTICAL_ALIGN_BOTTOM :
+							case BOTTOM :
 							default :
 							{
 								cropTop = 65536 * (normalHeight - availableImageHeight) / normalHeight;
@@ -908,12 +899,12 @@ public class JRDocxExporter extends JRAbstractExporter
 
 					break;
 				}
-				case JRImage.SCALE_IMAGE_RETAIN_SHAPE :
+				case RETAIN_SHAPE :
 				default :
 				{
 					if (availableImageHeight > 0)
 					{
-						double ratio = (double)normalWidth / (double)normalHeight;
+						double ratio = normalWidth / normalHeight;
 
 						if( ratio > availableImageWidth / (double)availableImageHeight )
 						{
@@ -945,7 +936,7 @@ public class JRDocxExporter extends JRAbstractExporter
 			docHelper.write("<w:drawing>\n");
 			docHelper.write("<wp:anchor distT=\"0\" distB=\"0\" distL=\"0\" distR=\"0\" simplePos=\"0\" relativeHeight=\"0\" behindDoc=\"0\" locked=\"1\" layoutInCell=\"1\" allowOverlap=\"1\">");
 			docHelper.write("<wp:simplePos x=\"0\" y=\"0\"/>");
-			docHelper.write("<wp:positionH relativeFrom=\"column\"><wp:align>" + DocxParagraphHelper.getHorizontalAlignment(new Byte(image.getHorizontalAlignment())) + "</wp:align></wp:positionH>");
+			docHelper.write("<wp:positionH relativeFrom=\"column\"><wp:align>" + DocxParagraphHelper.getHorizontalAlignment(image.getHorizontalAlignmentValue()) + "</wp:align></wp:positionH>");
 			docHelper.write("<wp:positionV relativeFrom=\"line\"><wp:posOffset>0</wp:posOffset></wp:positionV>");
 //			docHelper.write("<wp:positionV relativeFrom=\"line\"><wp:align>" + CellHelper.getVerticalAlignment(new Byte(image.getVerticalAlignment())) + "</wp:align></wp:positionV>");
 			
@@ -960,13 +951,21 @@ public class JRDocxExporter extends JRAbstractExporter
 			docHelper.write("<a:blip r:embed=\"" + getImagePath(renderer, image.isLazy(), gridCell) + "\"/>");
 			docHelper.write("<a:srcRect");
 			if (cropLeft > 0)
+			{
 				docHelper.write(" l=\"" + (int)cropLeft + "\"");
+			}
 			if (cropTop > 0)
+			{
 				docHelper.write(" t=\"" + (int)cropTop + "\"");
+			}
 			if (cropRight > 0)
+			{
 				docHelper.write(" r=\"" + (int)cropRight + "\"");
+			}
 			if (cropBottom > 0)
+			{
 				docHelper.write(" b=\"" + (int)cropBottom + "\"");
+			}
 			docHelper.write("/>");
 			docHelper.write("<a:stretch><a:fillRect/></a:stretch>\n");
 			docHelper.write("</pic:blipFill>\n");
@@ -1058,7 +1057,7 @@ public class JRDocxExporter extends JRAbstractExporter
 			writer.write("/>\n");
 		}
 
-		if (mainHyperlink.getHyperlinkType() != JRHyperlink.HYPERLINK_TYPE_NONE)
+		if (mainHyperlink.getHyperlinkTypeValue() != NONE)
 		{
 			writer.write("  <area shape=\"default\"");
 			writeImageAreaHyperlink(mainHyperlink);
@@ -1148,7 +1147,7 @@ public class JRDocxExporter extends JRAbstractExporter
 //		tableHelper.getCellHelper().exportProps(gridCell);
 
 		boolean appendBackcolor =
-			frame.getMode() == JRElement.MODE_OPAQUE
+			frame.getModeValue() == ModeEnum.OPAQUE
 			&& (backcolor == null || frame.getBackcolor().getRGB() != backcolor.getRGB());
 
 		if (appendBackcolor)
@@ -1183,7 +1182,7 @@ public class JRDocxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected void exportGenericElement(DocxTableHelper tableHelper, JRGenericPrintElement element, JRExporterGridCell gridCell) throws JRException
+	protected void exportGenericElement(DocxTableHelper tableHelper, JRGenericPrintElement element, JRExporterGridCell gridCell)
 	{
 		GenericElementDocxHandler handler = (GenericElementDocxHandler) 
 		GenericElementHandlerEnviroment.getHandler(
@@ -1223,56 +1222,56 @@ public class JRDocxExporter extends JRAbstractExporter
 	}
 
 
-	private float getXAlignFactor(JRPrintImage image)
-	{
-		float xalignFactor = 0f;
-		switch (image.getHorizontalAlignment())
-		{
-			case JRAlignment.HORIZONTAL_ALIGN_RIGHT :
-			{
-				xalignFactor = 1f;
-				break;
-			}
-			case JRAlignment.HORIZONTAL_ALIGN_CENTER :
-			{
-				xalignFactor = 0.5f;
-				break;
-			}
-			case JRAlignment.HORIZONTAL_ALIGN_LEFT :
-			default :
-			{
-				xalignFactor = 0f;
-				break;
-			}
-		}
-		return xalignFactor;
-	}
+//	private float getXAlignFactor(JRPrintImage image)
+//	{
+//		float xalignFactor = 0f;
+//		switch (image.getHorizontalAlignmentValue())
+//		{
+//			case RIGHT :
+//			{
+//				xalignFactor = 1f;
+//				break;
+//			}
+//			case CENTER :
+//			{
+//				xalignFactor = 0.5f;
+//				break;
+//			}
+//			case LEFT :
+//			default :
+//			{
+//				xalignFactor = 0f;
+//				break;
+//			}
+//		}
+//		return xalignFactor;
+//	}
 
 
-	private float getYAlignFactor(JRPrintImage image)
-	{
-		float yalignFactor = 0f;
-		switch (image.getVerticalAlignment())
-		{
-			case JRAlignment.VERTICAL_ALIGN_BOTTOM :
-			{
-				yalignFactor = 1f;
-				break;
-			}
-			case JRAlignment.VERTICAL_ALIGN_MIDDLE :
-			{
-				yalignFactor = 0.5f;
-				break;
-			}
-			case JRAlignment.VERTICAL_ALIGN_TOP :
-			default :
-			{
-				yalignFactor = 0f;
-				break;
-			}
-		}
-		return yalignFactor;
-	}
+//	private float getYAlignFactor(JRPrintImage image)
+//	{
+//		float yalignFactor = 0f;
+//		switch (image.getVerticalAlignmentValue())
+//		{
+//			case BOTTOM :
+//			{
+//				yalignFactor = 1f;
+//				break;
+//			}
+//			case MIDDLE :
+//			{
+//				yalignFactor = 0.5f;
+//				break;
+//			}
+//			case TOP :
+//			default :
+//			{
+//				yalignFactor = 0f;
+//				break;
+//			}
+//		}
+//		return yalignFactor;
+//	}
 
 	protected boolean startHyperlink(JRPrintHyperlink link, boolean isText)
 	{
@@ -1323,14 +1322,14 @@ public class JRDocxExporter extends JRAbstractExporter
 	protected String getHyperlinkTarget(JRPrintHyperlink link)
 	{
 		String target = null;
-		switch(link.getHyperlinkTarget())
+		switch(link.getHyperlinkTargetValue())
 		{
-			case JRHyperlink.HYPERLINK_TARGET_SELF :
+			case SELF :
 			{
 				target = "_self";
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TARGET_BLANK :
+			case BLANK :
 			default :
 			{
 				target = "_blank";
@@ -1347,9 +1346,9 @@ public class JRDocxExporter extends JRAbstractExporter
 		JRHyperlinkProducer customHandler = getCustomHandler(link);
 		if (customHandler == null)
 		{
-			switch(link.getHyperlinkType())
+			switch(link.getHyperlinkTypeValue())
 			{
-				case JRHyperlink.HYPERLINK_TYPE_REFERENCE :
+				case REFERENCE :
 				{
 					if (link.getHyperlinkReference() != null)
 					{
@@ -1357,7 +1356,7 @@ public class JRDocxExporter extends JRAbstractExporter
 					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_LOCAL_ANCHOR :
+				case LOCAL_ANCHOR :
 				{
 //					if (link.getHyperlinkAnchor() != null)
 //					{
@@ -1365,7 +1364,7 @@ public class JRDocxExporter extends JRAbstractExporter
 //					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_LOCAL_PAGE :
+				case LOCAL_PAGE :
 				{
 //					if (link.getHyperlinkPage() != null)
 //					{
@@ -1373,7 +1372,7 @@ public class JRDocxExporter extends JRAbstractExporter
 //					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_REMOTE_ANCHOR :
+				case REMOTE_ANCHOR :
 				{
 					if (
 						link.getHyperlinkReference() != null &&
@@ -1384,7 +1383,7 @@ public class JRDocxExporter extends JRAbstractExporter
 					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_REMOTE_PAGE :
+				case REMOTE_PAGE :
 				{
 //					if (
 //						link.getHyperlinkReference() != null &&
@@ -1395,7 +1394,7 @@ public class JRDocxExporter extends JRAbstractExporter
 //					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_NONE :
+				case NONE :
 				default :
 				{
 					break;
