@@ -106,37 +106,42 @@ public class JRPptxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected PptxZip pptxZip;
-	protected PptxPresentationHelper presentationHelper;
-	protected PptxPresentationRelsHelper presentationRelsHelper;
-	protected PptxContentTypesHelper ctHelper;
-	protected PptxSlideHelper slideHelper;
-	protected PptxSlideRelsHelper slideRelsHelper;
-	protected Writer presentationWriter;
+	protected PptxZip pptxZip = null;
+	protected PptxPresentationHelper presentationHelper = null;
+	protected PptxPresentationRelsHelper presentationRelsHelper = null;
+	protected PptxContentTypesHelper ctHelper = null;
+	protected PptxSlideHelper slideHelper = null;
+	protected PptxSlideRelsHelper slideRelsHelper = null;
+	protected Writer presentationWriter = null;
 
-	protected JRExportProgressMonitor progressMonitor;
-	protected Map rendererToImagePathMap;
+	protected JRExportProgressMonitor progressMonitor = null;
+	protected Map rendererToImagePathMap = null;
 	protected Map imageMaps;
-	protected List imagesToProcess;
-//	protected Map hyperlinksMap;
+	protected List imagesToProcess = null;
+//	protected Map hyperlinksMap = null;
 
-	protected int reportIndex;
-	protected int pageIndex;
-	protected List frameIndexStack;
-	protected int elementIndex;
+	protected int reportIndex = 0;
+	protected int pageIndex = 0;
+	protected List frameIndexStack = null;
+	protected int elementIndex = 0;
 	protected boolean startPage;
 
 	/**
 	 * used for counting the total number of sheets
 	 */
-	protected int slideIndex;
+	protected int slideIndex = 0;
 	
+	/**
+	 *
+	 */
+	protected boolean isWrapBreakWord = false;
+
 	/**
 	 * @deprecated
 	 */
-	protected Map fontMap;
+	protected Map fontMap = null;
 
-	private PptxRunHelper runHelper;
+	private PptxRunHelper runHelper = null;
 
 
 	protected class ExporterContext extends BaseExporterContext implements JRPptxExporterContext
@@ -889,6 +894,12 @@ public class JRPptxExporter extends JRAbstractExporter
 		slideHelper.write("\"/>\n");
 		slideHelper.write("    <a:lstStyle/>\n");
 
+//		if (isWrapBreakWord)
+//		{
+//			styleBuffer.append("width: " + gridCell.width + "; ");
+//			styleBuffer.append("word-wrap: break-word; ");
+//		}
+
 //		if (styleBuffer.length() > 0)
 //		{
 //			writer.write(" style=\"");
