@@ -50,8 +50,8 @@ public class XlsxRunHelper extends BaseHelper
 	/**
 	 *
 	 */
-	private Map fontMap;
-	private String exporterKey;
+	private Map fontMap = null;
+	private String exporterKey = null;
 
 
 	/**
