@@ -36,32 +36,25 @@ import net.sf.jasperreports.engine.util.FileBufferedWriter;
  */
 public class XlsxSheetHelper extends BaseHelper
 {
-	private int rowIndex;
+	private int rowIndex = 0;
 	
 	private FileBufferedWriter colsWriter = new FileBufferedWriter();
 	private FileBufferedWriter mergedCellsWriter = new FileBufferedWriter();
 	private FileBufferedWriter hyperlinksWriter = new FileBufferedWriter();
 	
-	private boolean isCollapseRowSpan;
-	
 	/**
 	 *
 	 */
-	private XlsxSheetRelsHelper sheetRelsHelper;//FIXMEXLSX truly embed the rels helper here and no longer have it available from outside; check drawing rels too
+	private XlsxSheetRelsHelper sheetRelsHelper = null;//FIXMEXLSX truly embed the rels helper here and no longer have it available from outside; check drawing rels too
 
 	/**
 	 * 
 	 */
-	public XlsxSheetHelper(
-		Writer writer, 
-		XlsxSheetRelsHelper sheetRelsHelper,
-		boolean isCollapseRowSpan
-		)
+	public XlsxSheetHelper(Writer writer, XlsxSheetRelsHelper sheetRelsHelper)
 	{
 		super(writer);
 		
 		this.sheetRelsHelper = sheetRelsHelper;
-		this.isCollapseRowSpan = isCollapseRowSpan;
 	}
 
 	/**
@@ -92,7 +85,7 @@ public class XlsxSheetHelper extends BaseHelper
 		{
 			if (!colsWriter.isEmpty())
 			{
-				write("<cols>\n");
+				write("<cols>\n");//FIXMEXLSX check count attribute
 				colsWriter.writeData(writer);
 				write("</cols>\n");
 			}
@@ -101,13 +94,13 @@ public class XlsxSheetHelper extends BaseHelper
 		write("</sheetData>\n");
 		if (!mergedCellsWriter.isEmpty())
 		{
-			write("<mergeCells>\n");
+			write("<mergeCells>\n");//FIXMEXLSX check count attribute
 			mergedCellsWriter.writeData(writer);
 			write("</mergeCells>\n");
 		}
 		if (!hyperlinksWriter.isEmpty())
 		{
-			write("<hyperlinks>\n");
+			write("<hyperlinks>\n");//FIXMEXLSX check count attribute
 			hyperlinksWriter.writeData(writer);
 			write("</hyperlinks>\n");
 		}
@@ -145,7 +138,7 @@ public class XlsxSheetHelper extends BaseHelper
 		{
 			if (!colsWriter.isEmpty())
 			{
-				write("<cols>\n");
+				write("<cols>\n");//FIXMEXLSX check count attribute
 				colsWriter.writeData(writer);
 				write("</cols>\n");
 			}
@@ -160,9 +153,7 @@ public class XlsxSheetHelper extends BaseHelper
 	 */
 	public void exportMergedCells(int row, int col, int rowSpan, int colSpan) 
 	{
-		rowSpan = isCollapseRowSpan ? 1 : rowSpan;
-		
-		if (rowSpan > 1	|| colSpan > 1)
+		if (rowSpan > 1 || colSpan > 1)
 		{
 			String ref = 
 				XlsxCellHelper.getColumIndexLetter(col) + (row + 1)
