@@ -39,30 +39,17 @@ public class XlsxStyleInfo
 	/**
 	 *
 	 */
-	protected int formatIndex; 
-	protected int fontIndex; 
-	protected int borderIndex; 
-	protected String backcolor; 
-	protected String horizontalAlign;
-	protected String verticalAlign;
-	protected boolean isWrapText = true;
-	protected boolean isHidden;
-	protected boolean isLocked;
+	protected int fontIndex = 0; 
+	protected int borderIndex = 0; 
+	protected String backcolor = null; 
+	protected String horizontalAlign = null;
+	protected String verticalAlign = null;
 
 	/**
 	 *
 	 */
-	public XlsxStyleInfo(
-		int formatIndex, 
-		int fontIndex, 
-		int borderIndex, 
-		JRExporterGridCell gridCell, 
-		boolean isWrapText,
-		boolean isHidden,
-		boolean isLocked
-		)
+	public XlsxStyleInfo(int fontIndex, int borderIndex, JRExporterGridCell gridCell)
 	{
-		this.formatIndex = formatIndex;
 		this.fontIndex = fontIndex;
 		this.borderIndex = borderIndex;
 		
@@ -83,16 +70,11 @@ public class XlsxStyleInfo
 			this.horizontalAlign = XlsxParagraphHelper.getHorizontalAlignment(align.getHorizontalAlignmentValue());//FIXMEXLSX use common util
 			this.verticalAlign = DocxCellHelper.getVerticalAlignment(align.getVerticalAlignmentValue());//FIXMEXLSX use common util
 		}
-		
-		this.isWrapText = isWrapText;
-		this.isHidden = isHidden;
-		this.isLocked = isLocked;
 	}
 	
 	public String getId()
 	{
 		return 
-		formatIndex + "|" + fontIndex + "|" + borderIndex + "|" + backcolor + "|" + horizontalAlign + "|" + verticalAlign 
-		+ "|" + isWrapText + "|" + isHidden + "|" + isLocked;
+			fontIndex + "|" + borderIndex + "|" + backcolor + "|" + horizontalAlign + "|" + verticalAlign;
 	}
 }
