@@ -57,17 +57,21 @@ import net.sf.jasperreports.charts.JRScatterPlot;
 import net.sf.jasperreports.charts.JRThermometerPlot;
 import net.sf.jasperreports.charts.JRTimeSeriesPlot;
 import net.sf.jasperreports.charts.JRValueDisplay;
+import net.sf.jasperreports.charts.type.AxisPositionEnum;
+import net.sf.jasperreports.charts.type.EdgeEnum;
+import net.sf.jasperreports.charts.type.MeterShapeEnum;
+import net.sf.jasperreports.charts.type.ScaleTypeEnum;
 import net.sf.jasperreports.charts.util.JRMeterInterval;
 import net.sf.jasperreports.engine.JRChart;
 import net.sf.jasperreports.engine.JRChartDataset;
 import net.sf.jasperreports.engine.JRChartPlot;
-import net.sf.jasperreports.engine.JRElement;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRChartPlot.JRSeriesColor;
 import net.sf.jasperreports.engine.base.JRBaseFont;
+import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRFontUtil;
 import net.sf.jasperreports.engine.util.JRProperties;
 
@@ -137,7 +141,7 @@ import org.jfree.ui.TextAnchor;
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
  * @author Some enhancements by Barry Klawans (bklawans@users.sourceforge.net)
- * @version $Id: DefaultChartTheme.java 3181 2009-10-30 17:08:38Z teodord $
+ * @version $Id: DefaultChartTheme.java 3702 2010-04-07 12:28:51Z teodord $
  */
 public class DefaultChartTheme implements ChartTheme
 {
@@ -257,7 +261,7 @@ public class DefaultChartTheme implements ChartTheme
 				jfreeChart = createLineChart();
 				break;
 			case JRChart.CHART_TYPE_METER:
-				if (new Byte(JRMeterPlot.SHAPE_DIAL).equals(((JRMeterPlot)getPlot()).getShapeByte()))
+				if (MeterShapeEnum.DIAL ==((JRMeterPlot)getPlot()).getShapeValue())
 				{
 					jfreeChart = createDialChart();
 				}
@@ -318,7 +322,7 @@ public class DefaultChartTheme implements ChartTheme
 	 */
 	protected void configureChart(JFreeChart jfreeChart) throws JRException
 	{
-		if (getChart().getMode() == JRElement.MODE_OPAQUE)
+		if (getChart().getModeValue() == ModeEnum.OPAQUE)
 		{
 			jfreeChart.setBackgroundPaint(getChart().getBackcolor());
 		}
@@ -327,7 +331,7 @@ public class DefaultChartTheme implements ChartTheme
 			jfreeChart.setBackgroundPaint(TRANSPARENT_PAINT);
 		}
 		
-		RectangleEdge titleEdge = getEdge(getChart().getTitlePositionByte(), RectangleEdge.TOP);
+		RectangleEdge titleEdge = getEdge(getChart().getTitlePositionValue(), RectangleEdge.TOP);
 		
 		if (jfreeChart.getTitle() != null)
 		{
@@ -366,7 +370,7 @@ public class DefaultChartTheme implements ChartTheme
 			}
 
 			legend.setItemFont(JRFontUtil.getAwtFont(getChart().getLegendFont(), getLocale()));
-			legend.setPosition(getEdge(getChart().getLegendPositionByte(), RectangleEdge.BOTTOM));
+			legend.setPosition(getEdge(getChart().getLegendPositionValue(), RectangleEdge.BOTTOM));
 		}
 		
 		configurePlot(jfreeChart.getPlot());
@@ -399,7 +403,7 @@ public class DefaultChartTheme implements ChartTheme
 			// Handle rotation of the category labels.
 			CategoryAxis axis = ((CategoryPlot)plot).getDomainAxis();
 			// it's OK to use deprecated method here; avoiding it means attempting cast operations  
-			double labelRotation = getPlot().getLabelRotationDouble() == null ? 0d : getPlot().getLabelRotationDouble().doubleValue();
+			double labelRotation = getLabelRotation();
 			if (labelRotation == 90)
 			{
 				axis.setCategoryLabelPositions(CategoryLabelPositions.DOWN_90);
@@ -430,11 +434,7 @@ public class DefaultChartTheme implements ChartTheme
 				// colors.  To replace the defaults you have to specify at least two colors.
 				Paint[] colors = new Paint[DefaultDrawingSupplier.DEFAULT_PAINT_SEQUENCE.length + 1];
 				colors[0] = ((JRSeriesColor)seriesColors.first()).getColor();
-				for (int i = 0; i < DefaultDrawingSupplier.DEFAULT_PAINT_SEQUENCE.length; i++)
-				{
-					colors[i + 1] = DefaultDrawingSupplier.DEFAULT_PAINT_SEQUENCE[i];
-				}
-
+				System.arraycopy(DefaultDrawingSupplier.DEFAULT_PAINT_SEQUENCE, 0, colors, 1, DefaultDrawingSupplier.DEFAULT_PAINT_SEQUENCE.length);
 				plot.setDrawingSupplier(new DefaultDrawingSupplier(colors,
 						DefaultDrawingSupplier.DEFAULT_OUTLINE_PAINT_SEQUENCE,
 						DefaultDrawingSupplier.DEFAULT_STROKE_SEQUENCE,
@@ -524,22 +524,34 @@ public class DefaultChartTheme implements ChartTheme
 			{
 				NumberFormat fmt = NumberFormat.getInstance();
 				if (fmt instanceof DecimalFormat)
+				{
 					((DecimalFormat) fmt).applyPattern(tickLabelMask);
+				}
 				((NumberAxis)axis).setNumberFormatOverride(fmt);
 			}
 			else if (axis instanceof DateAxis)
 			{
 				DateFormat fmt;
 				if (tickLabelMask.equals("SHORT") || tickLabelMask.equals("DateFormat.SHORT"))
+				{
 					fmt = DateFormat.getDateInstance(DateFormat.SHORT);
+				}
 				else if (tickLabelMask.equals("MEDIUM") || tickLabelMask.equals("DateFormat.MEDIUM"))
+				{
 					fmt = DateFormat.getDateInstance(DateFormat.MEDIUM);
+				}
 				else if (tickLabelMask.equals("LONG") || tickLabelMask.equals("DateFormat.LONG"))
+				{
 					fmt = DateFormat.getDateInstance(DateFormat.LONG);
+				}
 				else if (tickLabelMask.equals("FULL") || tickLabelMask.equals("DateFormat.FULL"))
+				{
 					fmt = DateFormat.getDateInstance(DateFormat.FULL);
+				}
 				else
+				{
 					fmt = new SimpleDateFormat(tickLabelMask);
+				}
 
 				if (timeZone != null)
 				{
@@ -787,7 +799,7 @@ public class DefaultChartTheme implements ChartTheme
 
 		XYPlot xyPlot = (XYPlot)jfreeChart.getPlot();
 		JRBubblePlot bubblePlot = (JRBubblePlot)getPlot();
-		int scaleType = bubblePlot.getScaleTypeInteger() == null ? XYBubbleRenderer.SCALE_ON_RANGE_AXIS : bubblePlot.getScaleTypeInteger().intValue();
+		int scaleType = bubblePlot.getScaleTypeValue() == null ? ScaleTypeEnum.ON_RANGE_AXIS.getValue() : bubblePlot.getScaleTypeValue().getValue();
 		XYBubbleRenderer bubbleRenderer = new XYBubbleRenderer( scaleType );
 		xyPlot.setRenderer( bubbleRenderer );
 
@@ -1351,7 +1363,8 @@ public class DefaultChartTheme implements ChartTheme
 		IntervalXYDataset tmpDataset = (IntervalXYDataset)getDataset();
 
 		boolean isDate = true;
-		if( getChart().getDataset().getDatasetType() == JRChartDataset.XY_DATASET ){
+		if( getChart().getDataset().getDatasetType() == JRChartDataset.XY_DATASET )
+		{
 			isDate = false;
 		}
 
@@ -1575,7 +1588,9 @@ public class DefaultChartTheme implements ChartTheme
 	protected Range convertRange(JRDataRange dataRange) throws JRException
 	{
 		if (dataRange == null)
+		{
 			return null;
+		}
 
 		Number low = (Number)evaluateExpression(dataRange.getLowExpression());
 		Number high = (Number)evaluateExpression(dataRange.getHighExpression());
@@ -1594,7 +1609,9 @@ public class DefaultChartTheme implements ChartTheme
 	{
 		String label = interval.getLabel();
 		if (label == null)
+		{
 			label = "";
+		}
 
 		Range range = convertRange(interval.getDataRange());
 
@@ -1618,16 +1635,16 @@ public class DefaultChartTheme implements ChartTheme
 		MeterPlot chartPlot = new MeterPlot((ValueDataset)getDataset());
 
 		// Set the shape
-		int shape = jrPlot.getShapeByte() == null ? JRMeterPlot.SHAPE_PIE : jrPlot.getShapeByte().intValue();
+		MeterShapeEnum shape = jrPlot.getShapeValue() == null ? MeterShapeEnum.PIE : jrPlot.getShapeValue();
 		switch (shape)
 		{
-			case JRMeterPlot.SHAPE_CHORD :
+			case CHORD :
 				chartPlot.setDialShape(DialShape.CHORD);
 				break;
-			case JRMeterPlot.SHAPE_CIRCLE :
+			case CIRCLE :
 				chartPlot.setDialShape(DialShape.CIRCLE);
 				break;
-			case JRMeterPlot.SHAPE_PIE :
+			case PIE :
 			default :
 				chartPlot.setDialShape(DialShape.PIE);
 		}
@@ -1643,7 +1660,9 @@ public class DefaultChartTheme implements ChartTheme
 		// value
 		String units = jrPlot.getUnits();
 		if (units != null && units.length() > 0)
+		{
 			chartPlot.setUnits(units);
+		}
 
 		// Set the font used for tick labels
 		if(jrPlot.getTickLabelFont() != null)
@@ -1659,11 +1678,15 @@ public class DefaultChartTheme implements ChartTheme
 		// Set all the colors we support
 		Color color = jrPlot.getMeterBackgroundColor();
 		if (color != null)
+		{
 			chartPlot.setDialBackgroundPaint(color);
+		}
 
 		color = jrPlot.getNeedleColor();
 		if (color != null)
+		{
 			chartPlot.setNeedlePaint(color);
+		}
 
 		// Set how the value is displayed.
 		JRValueDisplay display = jrPlot.getValueDisplay();
@@ -1687,7 +1710,9 @@ public class DefaultChartTheme implements ChartTheme
 
 		color = jrPlot.getTickColor();
 		if (color != null)
+		{
 			chartPlot.setTickPaint(color);
+		}
 
 		// Now define all of the intervals, setting their range and color
 		List intervals = jrPlot.getIntervals();
@@ -1764,19 +1789,18 @@ public class DefaultChartTheme implements ChartTheme
 		}
 
 		// Set the location of where the value is displayed
-		byte valueLocation = jrPlot.getValueLocationByte() == null ? ThermometerPlot.BULB : jrPlot.getValueLocationByte().byteValue();
-		switch (valueLocation)
+		switch (jrPlot.getValueLocationValue())
 		{
-		  case JRThermometerPlot.LOCATION_NONE:
+		  case NONE:
 			 chartPlot.setValueLocation(ThermometerPlot.NONE);
 			 break;
-		  case JRThermometerPlot.LOCATION_LEFT:
+		  case LEFT:
 			 chartPlot.setValueLocation(ThermometerPlot.LEFT);
 			 break;
-		  case JRThermometerPlot.LOCATION_RIGHT:
+		  case RIGHT:
 			 chartPlot.setValueLocation(ThermometerPlot.RIGHT);
 			 break;
-		  case JRThermometerPlot.LOCATION_BULB:
+		  case BULB:
 		  default:
 			 chartPlot.setValueLocation(ThermometerPlot.BULB);
 			 break;
@@ -1839,7 +1863,9 @@ public class DefaultChartTheme implements ChartTheme
 		scale.setTickRadius(0.9);
 		scale.setTickLabelOffset(0.16);
 		if(jrPlot.getTickLabelFont() != null)
+		{
 			scale.setTickLabelFont(JRFontUtil.getAwtFont(jrPlot.getTickLabelFont(), getLocale()));
+		}
 		scale.setMajorTickStroke(new BasicStroke(1f));
 		scale.setMinorTickStroke(new BasicStroke(0.3f));
 		scale.setMajorTickPaint(jrPlot.getTickColor());
@@ -1855,8 +1881,9 @@ public class DefaultChartTheme implements ChartTheme
 			int size = Math.min(3, intervals.size());
 			int colorStep = 0;
 			if(size > 0)
+			{
 				colorStep = 255 / size;
-			
+			}
 			for(int i = 0; i < size; i++)
 			{
 				JRMeterInterval interval = (JRMeterInterval)intervals.get(i);
@@ -1891,7 +1918,9 @@ public class DefaultChartTheme implements ChartTheme
 
 			String pattern = display.getMask() != null ? display.getMask() : "#,##0.####";
 			if(pattern != null)
+			{
 				dvi.setNumberFormat( new DecimalFormat(pattern));
+			}
 			dvi.setRadius(0.15);
 			dvi.setValueAnchor(RectangleAnchor.CENTER);
 			dvi.setTextAnchor(TextAnchor.CENTER);
@@ -1910,7 +1939,9 @@ public class DefaultChartTheme implements ChartTheme
 			{
 				DialTextAnnotation dialAnnotation = new DialTextAnnotation(textLines[i]);
 				if(displayFont != null)
+				{
 					dialAnnotation.setFont(JRFontUtil.getAwtFont(displayFont, getLocale()));
+				}
 				dialAnnotation.setPaint(jrPlot.getValueDisplay().getColor());
 				dialAnnotation.setRadius(Math.sin(Math.PI/4.0) + i/10.0);
 				dialAnnotation.setAnchor(TextAnchor.CENTER);
@@ -1951,7 +1982,7 @@ public class DefaultChartTheme implements ChartTheme
 	 */
 	protected AxisLocation getChartAxisLocation(JRChartAxis chartAxis)
 	{
-		return chartAxis.getPositionByte() != null && chartAxis.getPositionByte().byteValue() == JRChartAxis.POSITION_RIGHT_OR_BOTTOM
+		return chartAxis.getPositionValue() != null && chartAxis.getPositionValue() == AxisPositionEnum.RIGHT_OR_BOTTOM
 				? AxisLocation.BOTTOM_OR_RIGHT 
 				: AxisLocation.TOP_OR_LEFT;
 	}
@@ -2078,32 +2109,43 @@ public class DefaultChartTheme implements ChartTheme
 //		}
 	}
 	
+
 	/**
 	 *
 	 */
-	private static RectangleEdge getEdge(Byte position, RectangleEdge defaultPosition)
+	@SuppressWarnings("deprecation")
+	private double getLabelRotation()
+	{
+		return getPlot().getLabelRotationDouble() == null ? 0d : getPlot().getLabelRotationDouble().doubleValue();
+	}
+
+	
+	/**
+	 *
+	 */
+	private static RectangleEdge getEdge(EdgeEnum position, RectangleEdge defaultPosition)
 	{
 		RectangleEdge edge = defaultPosition;
 		if(position != null)
 		{
-			switch (position.byteValue())
+			switch (position)
 			{
-				case JRChart.EDGE_TOP :
+				case TOP :
 				{
 					edge = RectangleEdge.TOP;
 					break;
 				}
-				case JRChart.EDGE_BOTTOM :
+				case BOTTOM :
 				{
 					edge = RectangleEdge.BOTTOM;
 					break;
 				}
-				case JRChart.EDGE_LEFT :
+				case LEFT :
 				{
 					edge = RectangleEdge.LEFT;
 					break;
 				}
-				case JRChart.EDGE_RIGHT :
+				case RIGHT :
 				{
 					edge = RectangleEdge.RIGHT;
 					break;
@@ -2142,4 +2184,5 @@ public class DefaultChartTheme implements ChartTheme
 	{
 		return getChart().getShowLegend() == null ? true : getChart().getShowLegend().booleanValue();
 	}
+
 }
