@@ -76,7 +76,6 @@ import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
 import net.sf.jasperreports.engine.type.FooterPositionEnum;
 import net.sf.jasperreports.engine.type.OrientationEnum;
 import net.sf.jasperreports.engine.type.PrintOrderEnum;
-import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.type.WhenNoDataTypeEnum;
 import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
 import net.sf.jasperreports.engine.util.DefaultFormatFactory;
@@ -93,7 +92,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseFiller.java 3953 2010-09-20 13:54:34Z teodord $
+ * @version $Id: JRBaseFiller.java 3860 2010-06-03 14:38:36Z lucianc $
  */
 public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualPrintPage.IdentityDataProvider//, JRDefaultFontProvider
 {
@@ -174,7 +173,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	/**
 	 *
 	 */
-	protected JRBaseFiller parentFiller;
+	protected JRBaseFiller parentFiller = null;
 	protected JRFillSubreport parentElement;
 
 	private final JRFillObjectFactory factory;
@@ -184,46 +183,44 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	/**
 	 *
 	 */
-	private boolean isInterrupted;
+	private boolean isInterrupted = false;
 
 	/**
 	 *
 	 */
-	protected String name;
+	protected String name = null;
 
 	protected int columnCount = 1;
 
 	protected PrintOrderEnum printOrder = PrintOrderEnum.VERTICAL;
 
-	protected RunDirectionEnum columnDirection = RunDirectionEnum.LTR;
+	protected int pageWidth = 0;
 
-	protected int pageWidth;
-
-	protected int pageHeight;
+	protected int pageHeight = 0;
 
 	protected OrientationEnum orientation = OrientationEnum.PORTRAIT;
 
 	protected WhenNoDataTypeEnum whenNoDataType = WhenNoDataTypeEnum.NO_PAGES;
 
-	protected int columnWidth;
+	protected int columnWidth = 0;
 
-	protected int columnSpacing;
+	protected int columnSpacing = 0;
 
-	protected int leftMargin;
+	protected int leftMargin = 0;
 
-	protected int rightMargin;
+	protected int rightMargin = 0;
 
-	protected int topMargin;
+	protected int topMargin = 0;
 
-	protected int bottomMargin;
+	protected int bottomMargin = 0;
 
-	protected boolean isTitleNewPage;
+	protected boolean isTitleNewPage = false;
 
-	protected boolean isSummaryNewPage;
+	protected boolean isSummaryNewPage = false;
 
-	protected boolean isSummaryWithPageHeaderAndFooter;
+	protected boolean isSummaryWithPageHeaderAndFooter = false;
 
-	protected boolean isFloatColumnFooter;
+	protected boolean isFloatColumnFooter = false;
 
 	/**
 	 * the resource missing handling type
@@ -234,49 +231,49 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	
 	protected List<JRTemplate> templates;
 
-	protected JRReportFont defaultFont;
+	protected JRReportFont defaultFont = null;
 
-	protected JRReportFont[] fonts;
+	protected JRReportFont[] fonts = null;
 
-	protected JRStyle defaultStyle;
+	protected JRStyle defaultStyle = null;
 
-	protected JRStyle[] styles;
+	protected JRStyle[] styles = null;
 
 	/**
 	 * Main report dataset.
 	 */
 	protected JRFillDataset mainDataset;
 
-	protected JRFillGroup[] groups;
+	protected JRFillGroup[] groups = null;
 
-	protected JRFillSection missingFillSection;
-	protected JRFillBand missingFillBand;
+	protected JRFillSection missingFillSection = null;
+	protected JRFillBand missingFillBand = null;
 
-	protected JRFillBand background;
+	protected JRFillBand background = null;
 
-	protected JRFillBand title;
+	protected JRFillBand title = null;
 
-	protected JRFillBand pageHeader;
+	protected JRFillBand pageHeader = null;
 
-	protected JRFillBand columnHeader;
+	protected JRFillBand columnHeader = null;
 
-	protected JRFillSection detailSection;
+	protected JRFillSection detailSection = null;
 
-	protected JRFillBand columnFooter;
+	protected JRFillBand columnFooter = null;
 
-	protected JRFillBand pageFooter;
+	protected JRFillBand pageFooter = null;
 
-	protected JRFillBand lastPageFooter;
+	protected JRFillBand lastPageFooter = null;
 
-	protected JRFillBand summary;
+	protected JRFillBand summary = null;
 
-	protected JRFillBand noData;
+	protected JRFillBand noData = null;
 
-	protected JRVirtualizer virtualizer;
+	protected JRVirtualizer virtualizer = null;
 
-	protected ClassLoader reportClassLoader;
+	protected ClassLoader reportClassLoader = null;
 
-	protected FormatFactory formatFactory;
+	protected FormatFactory formatFactory = null;
 
 	protected URLStreamHandlerFactory urlHandlerFactory;
 
@@ -292,11 +289,11 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	/**
 	 *
 	 */
-	protected JasperPrint jasperPrint;
+	protected JasperPrint jasperPrint = null;
 
-	protected JRPrintPage printPage;
+	protected JRPrintPage printPage = null;
 
-	protected int printPageStretchHeight;
+	protected int printPageStretchHeight = 0;
 
 	/**
 	 * List of {@link JRFillBand JRFillBand} objects containing all bands of the
@@ -339,28 +336,28 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 
 	private JRSubreportRunner subreportRunner;
 
-	protected SavePoint keepTogetherSavePoint;
+	protected SavePoint keepTogetherSavePoint = null;
 	
 
 	/**
 	 *
 	 */
-	protected boolean isCreatingNewPage;
-	protected boolean isNewPage;
-	protected boolean isNewColumn;
+	protected boolean isCreatingNewPage = false;
+	protected boolean isNewPage = false;
+	protected boolean isNewColumn = false;
 	protected boolean isNewGroup = true;
-	protected boolean isFirstPageBand;
-	protected boolean isFirstColumnBand;
+	protected boolean isFirstPageBand = false;
+	protected boolean isFirstColumnBand = false;
 
-	protected int columnIndex;
+	protected int columnIndex = 0;
 
-	protected int offsetX;
-	protected int offsetY;
-	protected int columnHeaderOffsetY;
-	protected int columnFooterOffsetY;
-	protected int lastPageColumnFooterOffsetY;
+	protected int offsetX = 0;
+	protected int offsetY = 0;
+	protected int columnHeaderOffsetY = 0;
+	protected int columnFooterOffsetY = 0;
+	protected int lastPageColumnFooterOffsetY = 0;
 
-	protected boolean isLastPageFooter;
+	protected boolean isLastPageFooter = false;
 
 	protected JRBaseFiller(JasperReport jasperReport, JREvaluator initEvaluator, JRFillSubreport parentElement) throws JRException
 	{
@@ -405,7 +402,6 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 		name = jasperReport.getName();
 		columnCount = jasperReport.getColumnCount();
 		printOrder = jasperReport.getPrintOrderValue();
-		columnDirection = jasperReport.getColumnDirection();
 		pageWidth = jasperReport.getPageWidth();
 		pageHeight = jasperReport.getPageHeight();
 		orientation = jasperReport.getOrientationValue();
@@ -2201,16 +2197,16 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 
 class SavePoint
 {
-	protected JRPrintPage page;
-	protected int columnIndex;
-	protected boolean isNewPage;
-	protected boolean isNewColumn;
-	protected int startOffsetY;
-	protected int endOffsetY;
-	protected int startElementIndex;
-	protected int endElementIndex;
-	protected int heightOffset;
-	protected int groupIndex;
+	protected JRPrintPage page = null;
+	protected int columnIndex = 0;
+	protected boolean isNewPage = false;
+	protected boolean isNewColumn = false;
+	protected int startOffsetY = 0;
+	protected int endOffsetY = 0;
+	protected int startElementIndex = 0;
+	protected int endElementIndex = 0;
+	protected int heightOffset = 0;
+	protected int groupIndex = 0;
 	protected FooterPositionEnum footerPosition = FooterPositionEnum.NORMAL;
 	protected List elementsToMove = new ArrayList();
 	
