@@ -89,7 +89,7 @@ import org.jfree.data.general.Dataset;
  * Fill-time implementation of a {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab}.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillCrosstab.java 4017 2010-10-27 12:10:17Z teodord $
+ * @version $Id: JRFillCrosstab.java 3657 2010-03-31 09:34:49Z teodord $
  */
 public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROriginProvider
 {
@@ -2085,7 +2085,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	 */
 	public byte getRunDirection()
 	{
-		return getRunDirectionValue() == null ? null : getRunDirectionValue().getValue();
+		return parentCrosstab.getRunDirectionValue().getValue();
 	}
 
 	/**
