@@ -54,23 +54,23 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
  * This is the base for band, frame and crosstab cell fillers.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillElementContainer.java 3941 2010-08-20 10:55:10Z teodord $
+ * @version $Id: JRFillElementContainer.java 3813 2010-05-19 19:35:39Z teodord $
  */
 public abstract class JRFillElementContainer extends JRFillElementGroup
 {
 	protected JRBaseFiller filler;
 	
-	private JRFillElement[] ySortedElements;
-	private JRFillElement[] stretchElements;
-	private JRFillElement[] bandBottomElements;
-	private JRFillElement[] removableElements;
+	private JRFillElement[] ySortedElements = null;
+	private JRFillElement[] stretchElements = null;
+	private JRFillElement[] bandBottomElements = null;
+	private JRFillElement[] removableElements = null;
 	
-	private boolean willOverflow;
-	protected boolean isOverflow;
+	private boolean willOverflow = false;
+	protected boolean isOverflow = false;
 	
-	private int stretchHeight;
-	private int firstY;
-	protected JRFillElement firstYElement;
+	private int stretchHeight = 0;
+	private int firstY = 0;
+	protected JRFillElement firstYElement = null;
 	
 	protected final JRFillExpressionEvaluator expressionEvaluator;
 	
