@@ -35,7 +35,7 @@ import net.sf.jasperreports.engine.JRVisitor;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillElementGroup.java 3940 2010-08-20 10:35:15Z teodord $
+ * @version $Id: JRFillElementGroup.java 3749 2010-04-16 17:19:49Z lucianc $
  */
 public class JRFillElementGroup implements JRElementGroup, JRFillCloneable
 {
@@ -45,19 +45,19 @@ public class JRFillElementGroup implements JRElementGroup, JRFillCloneable
 	 *
 	 */
 	protected List children = new ArrayList();
-	protected JRElementGroup elementGroup;
+	protected JRElementGroup elementGroup = null;
 
 	/**
 	 *
 	 */
-	protected JRFillElement[] elements;
+	protected JRFillElement[] elements = null;
 
 	/**
 	 *
 	 */
-	private JRElement topElementInGroup;
-	private JRElement bottomElementInGroup;
-	private int stretchHeightDiff;
+	private JRElement topElementInGroup = null;
+	private JRElement bottomElementInGroup = null;
+	private int stretchHeightDiff = 0;
 
 
 	/**
