@@ -37,6 +37,7 @@ import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRVisitor;
 import net.sf.jasperreports.engine.base.JRBaseElementGroup;
+import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
@@ -45,7 +46,7 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
  * Fill time implementation of a frame element.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillFrame.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRFillFrame.java 3420 2010-02-18 09:17:47Z teodord $
  */
 public class JRFillFrame extends JRFillElement implements JRFrame
 {
@@ -120,9 +121,9 @@ public class JRFillFrame extends JRFillElement implements JRFrame
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	/**
