@@ -140,7 +140,7 @@ import org.apache.commons.collections.SequencedHashMap;
  * A factory used to instantiate fill objects based on compiled report objects.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillObjectFactory.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRFillObjectFactory.java 3806 2010-05-18 10:02:44Z lucianc $
  */
 public class JRFillObjectFactory extends JRAbstractObjectFactory
 {
@@ -180,7 +180,7 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 		public void addStyle(JRStyle style)
 		{
 			styles.add(style);
-			stylesIdx.put(style.getName(), new Integer(styles.size() - 1));
+			stylesIdx.put(style.getName(), Integer.valueOf(styles.size() - 1));
 		}
 		
 		public void renamed(String oldName, String newName)
@@ -199,8 +199,7 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 	 */
 	protected JRFillObjectFactory(JRBaseFiller filler)
 	{
-		this.filler = filler;
-		this.evaluator = filler.calculator;
+		this(filler, filler.calculator);
 	}
 
 
@@ -272,6 +271,7 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 	/**
 	 *
 	 */
+	@SuppressWarnings("deprecation")
 	public JRReportFont getReportFont(JRReportFont font)
 	{
 		JRBaseReportFont fillFont = null;
