@@ -31,7 +31,7 @@ import net.sf.jasperreports.engine.JRSection;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillSection.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRFillSection.java 3751 2010-04-16 17:23:05Z lucianc $
  */
 public class JRFillSection implements JRSection, JROriginProvider
 {
@@ -41,9 +41,9 @@ public class JRFillSection implements JRSection, JROriginProvider
 	 */
 	protected JRBaseFiller filler;
 
-	protected JRFillBand[] bands;
+	protected JRFillBand[] bands = null;
 
-	protected JROrigin origin;
+	protected JROrigin origin = null;
 
 	private boolean isEmpty = true;
 	private boolean areAllPrintWhenExprNull = true;
