@@ -33,9 +33,6 @@ import net.sf.jasperreports.engine.JRChart;
 import net.sf.jasperreports.engine.JRCommonImage;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
-import net.sf.jasperreports.engine.JRElement;
-import net.sf.jasperreports.engine.JRGraphicElement;
-import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRHyperlinkHelper;
 import net.sf.jasperreports.engine.JRImage;
 import net.sf.jasperreports.engine.JRLineBox;
@@ -43,6 +40,14 @@ import net.sf.jasperreports.engine.JROrigin;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.base.JRBaseLineBox;
 import net.sf.jasperreports.engine.base.JRBasePen;
+import net.sf.jasperreports.engine.type.FillEnum;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.OnErrorTypeEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
@@ -53,7 +58,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * Image information shared by multiple print image objects.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplateImage.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRTemplateImage.java 3833 2010-05-27 14:16:59Z teodord $
  * @see JRTemplatePrintImage
  */
 public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlignment, JRBox, JRCommonImage
@@ -68,12 +73,12 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 	/**
 	 *
 	 */
-	private Byte scaleImage = null;
+	private ScaleImageEnum scaleImageValue = null;
 	private Boolean isUsingCache = Boolean.TRUE;
-	private Byte horizontalAlignment = null;
-	private Byte verticalAlignment = null;
+	private HorizontalAlignEnum horizontalAlignmentValue = null;
+	private VerticalAlignEnum verticalAlignmentValue = null;
 	protected boolean isLazy = false;
-	private byte onErrorType = JRImage.ON_ERROR_TYPE_ERROR;
+	protected OnErrorTypeEnum onErrorTypeValue = OnErrorTypeEnum.ERROR;
 	private String linkType;
 	private String linkTarget;
 
@@ -128,12 +133,12 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 		
 		lineBox = image.getLineBox().clone(this);
 
-		setScaleImage(image.getScaleImage());
+		setScaleImage(image.getScaleImageValue());
 		setUsingCache(image.isUsingCache());
-		setHorizontalAlignment(image.getHorizontalAlignment());
-		setVerticalAlignment(image.getVerticalAlignment());
+		setHorizontalAlignment(image.getHorizontalAlignmentValue());
+		setVerticalAlignment(image.getVerticalAlignmentValue());
 		setLazy(image.isLazy());
-		setOnErrorType(image.getOnErrorType());
+		setOnErrorType(image.getOnErrorTypeValue());
 		setLinkType(image.getLinkType());
 		setLinkTarget(image.getLinkTarget());
 	}
@@ -148,7 +153,7 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 		linePen = new JRBasePen(this);
 		
 		getLinePen().setLineWidth(0f);
-		setFill(JRGraphicElement.FILL_SOLID);
+		setFill(FillEnum.SOLID);
 		
 		copyLineBox(chart.getLineBox());
 
@@ -194,41 +199,65 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, JRElement.MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getScaleImageValue()}.
 	 */
 	public byte getScaleImage()
 	{
-		return JRStyleResolver.getScaleImage(this);
-	}
-		
-	/**
-	 *
-	 */
-	public Byte getOwnScaleImage()
-	{
-		return scaleImage;
-	}
-		
-	/**
-	 *
-	 */
-	public void setScaleImage(byte scaleImage)
-	{
-		this.scaleImage = new Byte(scaleImage);
+		return getScaleImageValue().getValue();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnScaleImageValue()}.
+	 */
+	public Byte getOwnScaleImage()
+	{
+		return getOwnScaleImageValue() == null ? null : getOwnScaleImageValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
+	 */
+	public void setScaleImage(byte scaleImage)
+	{
+		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
 	 */
 	public void setScaleImage(Byte scaleImage)
 	{
-		this.scaleImage = scaleImage;
+		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
+	}
+
+	/**
+	 * 
+	 */
+	public ScaleImageEnum getScaleImageValue()
+	{
+		return JRStyleResolver.getScaleImageValue(this);
+	}
+
+	/**
+	 * 
+	 */
+	public ScaleImageEnum getOwnScaleImageValue()
+	{
+		return this.scaleImageValue;
+	}
+
+	/**
+	 * 
+	 */
+	public void setScaleImage(ScaleImageEnum scaleImageValue)
+	{
+		this.scaleImageValue = scaleImageValue;
 	}
 
 	/**
@@ -248,67 +277,115 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public byte getHorizontalAlignment()
 	{
-		return JRStyleResolver.getHorizontalAlignment(this);
+		return getHorizontalAlignmentValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
 	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return horizontalAlignment;
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
 		
 	/**
 	 *
 	 */
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return JRStyleResolver.getHorizontalAlignmentValue(this);
+	}
+		
+	/**
+	 *
+	 */
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return horizontalAlignmentValue;
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
-		this.horizontalAlignment = new Byte(horizontalAlignment);
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
-		this.horizontalAlignment = horizontalAlignment;
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 		
 	/**
 	 *
 	 */
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignmentValue)
+	{
+		this.horizontalAlignmentValue = horizontalAlignmentValue;
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
 	public byte getVerticalAlignment()
 	{
-		return JRStyleResolver.getVerticalAlignment(this);
+		return getVerticalAlignmentValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
 	 */
 	public Byte getOwnVerticalAlignment()
 	{
-		return verticalAlignment;
+		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
 	}
 		
 	/**
 	 *
 	 */
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return JRStyleResolver.getVerticalAlignmentValue(this);
+	}
+		
+	/**
+	 *
+	 */
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return verticalAlignmentValue;
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
-		this.verticalAlignment = new Byte(verticalAlignment);
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
+	public void setVerticalAlignment(Byte verticalAlignment)
+	{
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
 	}
 		
 	/**
 	 *
 	 */
-	public void setVerticalAlignment(Byte verticalAlignment)
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignmentValue)
 	{
-		this.verticalAlignment = verticalAlignment;
+		this.verticalAlignmentValue = verticalAlignmentValue;
 	}
 		
 	/**
@@ -328,19 +405,44 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOnErrorTypeValue()}.
 	 */
 	public byte getOnErrorType()
 	{
-		return onErrorType;
+		return getOnErrorTypeValue().getValue();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setOnErrorType(OnErrorTypeEnum)}.
+	 */
+	public void setOnErrorType(byte onErrorType)
+	{
+		setOnErrorType(OnErrorTypeEnum.getByValue(onErrorType));
 	}
 
 	/**
 	 *
 	 */
-	public void setOnErrorType(byte onErrorType)
+	public OnErrorTypeEnum getOnErrorTypeValue()
 	{
-		this.onErrorType = onErrorType;
+		return this.onErrorTypeValue;
+	}
+
+	/**
+	 *
+	 */
+	public void setOnErrorType(OnErrorTypeEnum onErrorTypeValue)
+	{
+		this.onErrorTypeValue = onErrorTypeValue;
+	}
+
+	
+	/**
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
+	 */
+	public byte getHyperlinkType()
+	{
+		return getHyperlinkTypeValue().getValue();
 	}
 
 	
@@ -350,40 +452,66 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 	 * The actual hyperlink type is determined by {@link #getLinkType() getLinkType()}.
 	 * This method can is used to determine whether the hyperlink type is one of the
 	 * built-in types or a custom type. 
-	 * When hyperlink is of custom type, {@link JRHyperlink#HYPERLINK_TYPE_CUSTOM HYPERLINK_TYPE_CUSTOM} is returned.
+	 * When hyperlink is of custom type, {@link HyperlinkTypeEnum#CUSTOM CUSTOM} is returned.
 	 * </p>
 	 * @return one of the hyperlink type constants
 	 * @see #getLinkType()
 	 */
-	public byte getHyperlinkType()
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
 	{
-		return JRHyperlinkHelper.getHyperlinkType(getLinkType());
+		return JRHyperlinkHelper.getHyperlinkTypeValue(getLinkType());
 	}
 
 	
+	/**
+	 * @deprecated Replaced by {@link #setHyperlinkType(HyperlinkTypeEnum)}.
+	 */
+	protected void setHyperlinkType(byte hyperlinkType)
+	{
+		setHyperlinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
+	}
+		
+	
 	/**
 	 * Sets the link type as a built-in hyperlink type.
 	 * 
 	 * @param hyperlinkType the built-in hyperlink type
 	 * @see #getLinkType()
 	 */
-	protected void setHyperlinkType(byte hyperlinkType)
+	protected void setHyperlinkType(HyperlinkTypeEnum hyperlinkType)
 	{
 		setLinkType(JRHyperlinkHelper.getLinkType(hyperlinkType));
 	}
 		
+	
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHyperlinkTargetValue()}.
 	 */
 	public byte getHyperlinkTarget()
 	{
-		return JRHyperlinkHelper.getHyperlinkTarget(getLinkTarget());
+		return getHyperlinkTargetValue().getValue();
 	}
 		
 	/**
 	 *
 	 */
+	public HyperlinkTargetEnum getHyperlinkTargetValue()
+	{
+		return JRHyperlinkHelper.getHyperlinkTargetValue(getLinkTarget());
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHyperlinkTarget(HyperlinkTargetEnum)}.
+	 */
 	protected void setHyperlinkTarget(byte hyperlinkTarget)
+	{
+		setHyperlinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+	}
+	
+	/**
+	 *
+	 */
+	protected void setHyperlinkTarget(HyperlinkTargetEnum hyperlinkTarget)
 	{
 		setLinkTarget(JRHyperlinkHelper.getLinkTarget(hyperlinkTarget));
 	}
@@ -447,25 +575,6 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 	}
 	
 	
-	protected void normalizeLinkType()
-	{
-		if (linkType == null)
-		{
-			 linkType = JRHyperlinkHelper.getLinkType(hyperlinkType);
-		}
-		hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	}
-
-	protected void normalizeLinkTarget()
-	{
-		if (linkTarget == null)
-		{
-			 linkTarget = JRHyperlinkHelper.getLinkTarget(hyperlinkTarget);
-		}
-		hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
-	}
-
-
 	/**
 	 * 
 	 */
@@ -916,31 +1025,112 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 	}
 	
 	
-	/**
+	/*
 	 * These fields are only for serialization backward compatibility.
 	 */
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
+	private Byte horizontalAlignment = null;
+	/**
+	 * @deprecated
+	 */
+	private Byte verticalAlignment = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte border = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte topBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte leftBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte bottomBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte rightBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Color borderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color topBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color leftBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color bottomBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color rightBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer padding;
+	/**
+	 * @deprecated
+	 */
 	private Integer topPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer leftPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer bottomPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer rightPadding = null;
-	private byte hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	private byte hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkType;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkTarget;
+	/**
+	 * @deprecated
+	 */
+	private Byte scaleImage = null;
+	/**
+	 * @deprecated
+	 */
+	private byte onErrorType;
+
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
 		in.defaultReadObject();
 
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			horizontalAlignmentValue = HorizontalAlignEnum.getByValue(horizontalAlignment);
+			verticalAlignmentValue = VerticalAlignEnum.getByValue(verticalAlignment);
+			scaleImageValue = ScaleImageEnum.getByValue(scaleImage);
+			onErrorTypeValue = OnErrorTypeEnum.getByValue(onErrorType);
+
+			horizontalAlignment = null;
+			verticalAlignment = null;
+			scaleImage = null;
+		}
+		
 		if (lineBox == null)
 		{
 			lineBox = new JRBaseLineBox(this);
@@ -979,7 +1169,14 @@ public class JRTemplateImage extends JRTemplateGraphicElement implements JRAlign
 			rightPadding = null;
 		}
 
-		normalizeLinkType();
-		normalizeLinkTarget();
+		if (linkType == null)
+		{
+			 linkType = JRHyperlinkHelper.getLinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
+		}
+
+		if (linkTarget == null)
+		{
+			 linkTarget = JRHyperlinkHelper.getLinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+		}
 	}
 }
