@@ -35,7 +35,6 @@ import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPropertiesHolder;
 import net.sf.jasperreports.engine.JRPropertiesMap;
 import net.sf.jasperreports.engine.JRStyle;
-import net.sf.jasperreports.engine.PrintElementVisitor;
 import net.sf.jasperreports.engine.type.ModeEnum;
 
 
@@ -45,7 +44,7 @@ import net.sf.jasperreports.engine.type.ModeEnum;
  * store common attributes. 
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplatePrintElement.java 3991 2010-10-12 20:10:55Z lucianc $
+ * @version $Id: JRTemplatePrintElement.java 3411 2010-02-17 12:51:18Z teodord $
  */
 public class JRTemplatePrintElement implements JRPrintElement, Serializable
 {
@@ -59,12 +58,12 @@ public class JRTemplatePrintElement implements JRPrintElement, Serializable
 	/**
 	 *
 	 */
-	protected JRTemplateElement template;
+	protected JRTemplateElement template = null;
 
-	private int x;
-	private int y;
-	private int height;
-	private int width;
+	private int x = 0;
+	private int y = 0;
+	private int height = 0;
+	private int width = 0;
 
 	private JRPropertiesMap properties;
 	
@@ -360,10 +359,4 @@ public class JRTemplatePrintElement implements JRPrintElement, Serializable
 		
 		out.defaultWriteObject();
 	}
-
-	// we need to implement this method because the class is not abstract
-	public <T> void accept(PrintElementVisitor<T> visitor, T arg)
-	{
-		throw new UnsupportedOperationException();
-	}
 }
