@@ -32,7 +32,6 @@ import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.JRRenderable;
-import net.sf.jasperreports.engine.PrintElementVisitor;
 import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
@@ -49,7 +48,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * store common attributes. 
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplatePrintImage.java 3991 2010-10-12 20:10:55Z lucianc $
+ * @version $Id: JRTemplatePrintImage.java 3833 2010-05-27 14:16:59Z teodord $
  */
 public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implements JRPrintImage
 {
@@ -63,11 +62,11 @@ public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implemen
 	/**
 	 *
 	 */
-	private JRRenderable renderer;
-	private String anchorName;
-	private String hyperlinkReference;
-	private String hyperlinkAnchor;
-	private Integer hyperlinkPage;
+	private JRRenderable renderer = null;
+	private String anchorName = null;
+	private String hyperlinkReference = null;
+	private String hyperlinkAnchor = null;
+	private Integer hyperlinkPage = null;
 	private String hyperlinkTooltip;
 	private JRPrintHyperlinkParameters hyperlinkParameters;
 
@@ -982,9 +981,4 @@ public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implemen
 		this.hyperlinkTooltip = hyperlinkTooltip;
 	}
 
-	public <T> void accept(PrintElementVisitor<T> visitor, T arg)
-	{
-		visitor.visit(this, arg);
-	}
-
 }
