@@ -37,7 +37,6 @@ import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRStyledTextAttributeSelector;
-import net.sf.jasperreports.engine.PrintElementVisitor;
 import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
@@ -57,7 +56,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * store common attributes. 
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplatePrintText.java 3991 2010-10-12 20:10:55Z lucianc $
+ * @version $Id: JRTemplatePrintText.java 3715 2010-04-08 18:08:49Z teodord $
  */
 public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPrintText
 {
@@ -76,14 +75,14 @@ public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPri
 	private String textTruncateSuffix;
 	private short[] lineBreakOffsets;
 	private transient String truncatedText;
-	private float lineSpacingFactor;
-	private float leadingOffset;
+	private float lineSpacingFactor = 0;
+	private float leadingOffset = 0;
 	private RunDirectionEnum runDirectionValue;
-	private float textHeight;
-	private String anchorName;
-	private String hyperlinkReference;
-	private String hyperlinkAnchor;
-	private Integer hyperlinkPage;
+	private float textHeight = 0;
+	private String anchorName = null;
+	private String hyperlinkReference = null;
+	private String hyperlinkAnchor = null;
+	private Integer hyperlinkPage = null;
 	private String hyperlinkTooltip;
 	private JRPrintHyperlinkParameters hyperlinkParameters;
 
@@ -1619,10 +1618,5 @@ public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPri
 			runDirectionValue = RunDirectionEnum.getByValue(runDirection);
 		}
 	}
-
-	public <T> void accept(PrintElementVisitor<T> visitor, T arg)
-	{
-		visitor.visit(this, arg);
-	}
 	
 }
