@@ -38,7 +38,7 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
  * Rectangle information shared by multiple print rectangle objects.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplateRectangle.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRTemplateRectangle.java 3659 2010-03-31 10:20:49Z shertage $
  * @see JRTemplatePrintRectangle
  */
 public class JRTemplateRectangle extends JRTemplateGraphicElement implements JRCommonRectangle
@@ -53,7 +53,7 @@ public class JRTemplateRectangle extends JRTemplateGraphicElement implements JRC
 	/**
 	 *
 	 */
-	private Integer radius;
+	private Integer radius = null;
 
 
 	/**
