@@ -33,7 +33,7 @@ import net.sf.jasperreports.engine.JRRuntimeException;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRGraphEnvInitializer.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRGraphEnvInitializer.java 3767 2010-04-26 11:40:09Z lucianc $
  */
 public final class JRGraphEnvInitializer
 {
@@ -41,7 +41,7 @@ public final class JRGraphEnvInitializer
 	/**
 	 *
 	 */
-	private static Set AVAILABLE_FONT_FACE_NAMES; //NOPMD
+	private static Set AVAILABLE_FONT_FACE_NAMES = null; //NOPMD
 
 	/**
 	 *
