@@ -53,9 +53,9 @@ import net.sf.jasperreports.engine.JRRuntimeException;
  * </p> 
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRProperties.java 3188 2009-11-06 10:01:57Z teodord $
+ * @version $Id: JRProperties.java 3712 2010-04-08 09:53:09Z teodord $
  */
-public class JRProperties
+public final class JRProperties
 {
 	/**
 	 * The default properties file.
@@ -979,4 +979,9 @@ public class JRProperties
 		return value == null || value.length() == 0 ? null 
 				: new Character(value.charAt(0));
 	}
+	
+	
+	private JRProperties()
+	{
+	}
 }
