@@ -24,7 +24,6 @@
 package net.sf.jasperreports.engine.xml;
 
 import net.sf.jasperreports.engine.design.JRDesignSortField;
-import net.sf.jasperreports.engine.type.SortFieldTypeEnum;
 import net.sf.jasperreports.engine.type.SortOrderEnum;
 
 import org.xml.sax.Attributes;
@@ -32,7 +31,7 @@ import org.xml.sax.Attributes;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRSortFieldFactory.java 3955 2010-09-22 08:19:02Z teodord $
+ * @version $Id: JRSortFieldFactory.java 3616 2010-03-24 14:20:41Z teodord $
  */
 public class JRSortFieldFactory extends JRBaseFactory
 {
@@ -52,12 +51,6 @@ public class JRSortFieldFactory extends JRBaseFactory
 			sortField.setOrder(order);
 		}
 
-		SortFieldTypeEnum type = SortFieldTypeEnum.getByName(atts.getValue(JRXmlConstants.ATTRIBUTE_type));
-		if (type != null)
-		{
-			sortField.setType(type);
-		}
-
 		return sortField;
 	}
 	
