@@ -171,9 +171,9 @@ import org.xml.sax.SAXParseException;
  * a digester in order to prepare it for parsing JasperReports xml definition files.
  *
  * @author Peter Severin (peter_p_s@users.sourceforge.net)
- * @version $Id: JRXmlDigesterFactory.java 3203 2009-11-19 17:44:16Z lucianc $
+ * @version $Id: JRXmlDigesterFactory.java 3690 2010-04-06 12:23:17Z shertage $
  */
-public class JRXmlDigesterFactory
+public final class JRXmlDigesterFactory
 {
 
 	private static final Log log = LogFactory.getLog(JRXmlDigesterFactory.class);
@@ -1329,8 +1329,7 @@ public class JRXmlDigesterFactory
 			
 			JRSaxParserFactory factory = (JRSaxParserFactory) reportParserFactories
 					.getCachedInstance(parserFactoryClass);
-			SAXParser parser = factory.createParser();
-			return parser;
+			return factory.createParser();
 		}
 		catch (JRException e)
 		{
