@@ -34,12 +34,12 @@ import net.sf.jasperreports.engine.JasperPrint;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRSaveContributor.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRSaveContributor.java 3678 2010-04-02 12:13:06Z shertage $
  */
 public abstract class JRSaveContributor extends FileFilter
 {
-	private Locale locale;
-	private ResourceBundle resourceBundle;
+	private Locale locale = null;
+	private ResourceBundle resourceBundle = null;
 	
 	/**
 	 * 
